@@ -16,7 +16,7 @@
 %                              Bill Radcliffe                                 %
 %                                   2001                                      %
 %                                                                             %
-%  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -542,6 +542,7 @@ static Image *ReadEMFImage(const ImageInfo *image_info,
             image->rows=(size_t) floor(((image->rows*image->y_resolution)/
               DefaultResolution)+0.5);
         }
+      (void) flags;
       geometry=DestroyString(geometry);
     }
   hDC=GetDC(NULL);
@@ -613,10 +614,10 @@ static Image *ReadEMFImage(const ImageInfo *image_info,
       break;
     for (x=0; x < (ssize_t) image->columns; x++)
     {
-      SetRedPixelComponent(q,ScaleCharToQuantum(pBits->rgbRed));
-      SetGreenPixelComponent(q,ScaleCharToQuantum(pBits->rgbGreen));
-      SetBluePixelComponent(q,ScaleCharToQuantum(pBits->rgbBlue));
-      SetOpacityPixelComponent(q,OpaqueOpacity);
+      SetPixelRed(q,ScaleCharToQuantum(pBits->rgbRed));
+      SetPixelGreen(q,ScaleCharToQuantum(pBits->rgbGreen));
+      SetPixelBlue(q,ScaleCharToQuantum(pBits->rgbBlue));
+      SetPixelOpacity(q,OpaqueOpacity);
       pBits++;
       q++;
     }
