@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -271,11 +271,11 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
     for (x=0; x < (ssize_t) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
-        histogram[ScaleQuantumToChar(GetRedPixelComponent(p))].red++;
+        histogram[ScaleQuantumToChar(GetPixelRed(p))].red++;
       if ((channel & GreenChannel) != 0)
-        histogram[ScaleQuantumToChar(GetGreenPixelComponent(p))].green++;
+        histogram[ScaleQuantumToChar(GetPixelGreen(p))].green++;
       if ((channel & BlueChannel) != 0)
-        histogram[ScaleQuantumToChar(GetBluePixelComponent(p))].blue++;
+        histogram[ScaleQuantumToChar(GetPixelBlue(p))].blue++;
       p++;
     }
   }
@@ -294,7 +294,7 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
     Initialize histogram image.
   */
   exception=(&image->exception);
-  (void) QueryColorDatabase("#000000",&histogram_image->background_color,
+  (void) QueryColorDatabase("#000",&histogram_image->background_color,
     &image->exception);
   (void) SetImageBackgroundColor(histogram_image);
   for (x=0; x < (ssize_t) histogram_image->columns; x++)
@@ -308,7 +308,7 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
         r=q+y;
         for ( ; y < (ssize_t) histogram_image->rows; y++)
         {
-          r->red=(Quantum) QuantumRange;
+          SetPixelRed(r,QuantumRange);
           r++;
         }
       }
@@ -318,7 +318,7 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
         r=q+y;
         for ( ; y < (ssize_t) histogram_image->rows; y++)
         {
-          r->green=(Quantum) QuantumRange;
+          SetPixelGreen(r,QuantumRange);
           r++;
         }
       }
@@ -328,7 +328,7 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
         r=q+y;
         for ( ; y < (ssize_t) histogram_image->rows; y++)
         {
-          r->blue=(Quantum) QuantumRange;
+          SetPixelBlue(r,QuantumRange);
           r++;
         }
       }
@@ -382,7 +382,7 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
   write_info=CloneImageInfo(image_info);
   (void) SetImageInfo(write_info,1,&image->exception);
   if (LocaleCompare(write_info->magick,"HISTOGRAM") == 0)
-    (void) FormatMagickString(histogram_image->filename,MaxTextExtent,
+    (void) FormatLocaleString(histogram_image->filename,MaxTextExtent,
       "miff:%s",write_info->filename);
   status=WriteImage(write_info,histogram_image);
   histogram_image=DestroyImage(histogram_image);
