@@ -18,7 +18,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -422,7 +422,7 @@ static MagickBooleanType ParseImageResourceBlocks(Image *image,
 
   if (length < 16)
     return(MagickFalse);
-  profile=AcquireStringInfo(length);
+  profile=BlobToStringInfo((const void *) NULL,length);
   SetStringInfoDatum(profile,blocks);
   (void) SetImageProfile(image,"8bim",profile);
   profile=DestroyStringInfo(profile);
@@ -674,8 +674,6 @@ static MagickBooleanType ReadPSDLayer(Image *image,const size_t channels,
                     q++;
                     x++;
                   }
-                  q--;
-                  x--;
                 }
             }
           break;
@@ -2027,7 +2025,7 @@ static void RemoveResolutionFromResourceBlock(StringInfo *bim_profile)
     p=PushShortPixel(MSBEndian,p,&id);
     p=PushShortPixel(MSBEndian,p,&short_sans);
     p=PushLongPixel(MSBEndian,p,&count);
-    if ((id == 0x000003ed) && (PSDQuantum(count) < (length-12)))
+    if ((id == 0x000003ed) && (PSDQuantum(count) < (ssize_t) (length-12)))
       {
         (void) CopyMagickMemory(q,q+PSDQuantum(count)+12,length-
           (PSDQuantum(count)+12)-(q-datum));
@@ -2267,10 +2265,12 @@ static MagickBooleanType WritePSDImage(const ImageInfo *image_info,Image *image)
       while (next_image != NULL)
       {
         next_image->compression=NoCompression;
-        (void) WriteBlobMSBLong(image,0);
-        (void) WriteBlobMSBLong(image,0);
-        (void) WriteBlobMSBLong(image,(unsigned int) next_image->rows);
-        (void) WriteBlobMSBLong(image,(unsigned int) next_image->columns);
+        (void) WriteBlobMSBLong(image,(unsigned int) next_image->page.y);
+        (void) WriteBlobMSBLong(image,(unsigned int) next_image->page.x);
+        (void) WriteBlobMSBLong(image,(unsigned int) next_image->page.y+
+          next_image->rows);
+        (void) WriteBlobMSBLong(image,(unsigned int) next_image->page.x+
+          next_image->columns);
         packet_size=next_image->depth > 8 ? 2UL : 1UL;
         channel_size=(unsigned int) ((packet_size*next_image->rows*
           next_image->columns)+2);
