@@ -17,7 +17,7 @@
 %                                 March 2011                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -170,10 +170,10 @@ static Image *ReadWEBPImage(const ImageInfo *image_info,
       break;
     for (x=0; x < (ssize_t) image->columns; x++)
     {
-      q->red=ScaleCharToQuantum(*p++);
-      q->green=ScaleCharToQuantum(*p++);
-      q->blue=ScaleCharToQuantum(*p++);
-      q->opacity=(Quantum) (QuantumRange-ScaleCharToQuantum(*p++));
+      SetPixelRed(q,ScaleCharToQuantum(*p++));
+      SetPixelGreen(q,ScaleCharToQuantum(*p++));
+      SetPixelBlue(q,ScaleCharToQuantum(*p++));
+      SetPixelAlpha(q,ScaleCharToQuantum(*p++));
       if (q->opacity != OpaqueOpacity)
         image->matte=MagickTrue;
       q++;
@@ -371,12 +371,13 @@ static MagickBooleanType WriteWEBPImage(const ImageInfo *image_info,
       break;
     for (x=0; x < (ssize_t) image->columns; x++)
     {
-      *q++=ScaleQuantumToChar(GetRedPixelComponent(p));
-      *q++=ScaleQuantumToChar(GetGreenPixelComponent(p));
-      *q++=ScaleQuantumToChar(GetBluePixelComponent(p));
+      *q++=ScaleQuantumToChar(GetPixelRed(p));
+      *q++=ScaleQuantumToChar(GetPixelGreen(p));
+      *q++=ScaleQuantumToChar(GetPixelBlue(p));
       if (image->matte != MagickFalse)
         *q++=ScaleQuantumToChar((Quantum) (QuantumRange-
-          (image->matte != MagickFalse ? p->opacity : OpaqueOpacity)));
+          (image->matte != MagickFalse ? GetPixelOpacity(p) :
+          OpaqueOpacity)));
       p++;
     }
     status=SetImageProgress(image,SaveImageTag,(MagickOffsetType) y,
