@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -105,11 +105,6 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
   InterlaceType
     interlace;
 
-  ssize_t
-    horizontal_factor,
-    vertical_factor,
-    y;
-
   MagickBooleanType
     status;
 
@@ -126,7 +121,11 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
     *p;
 
   ssize_t
-    count;
+    count,
+    horizontal_factor,
+    quantum,
+    vertical_factor,
+    y;
 
   unsigned char
     *scanline;
@@ -144,7 +143,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
   image=AcquireImage(image_info);
   if ((image->columns == 0) || (image->rows == 0))
     ThrowReaderException(OptionError,"MustSpecifyImageSize");
-  image->depth=8;
+  quantum=image->depth <= 8 ? 1 : 2;
   interlace=image_info->interlace;
   horizontal_factor=2;
   vertical_factor=2;
@@ -192,10 +191,10 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
   */
   if (interlace == NoInterlace)
     scanline=(unsigned char *) AcquireQuantumMemory((size_t) 2UL*
-      image->columns+2UL,sizeof(*scanline));
+      image->columns+2UL,quantum*sizeof(*scanline));
   else
     scanline=(unsigned char *) AcquireQuantumMemory((size_t) image->columns,
-      sizeof(*scanline));
+      quantum*sizeof(*scanline));
   if (scanline == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   do
@@ -228,7 +227,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
       if (interlace == NoInterlace)
         {
           if ((y > 0) || (GetPreviousImageInList(image) == (Image *) NULL))
-            count=ReadBlob(image,(size_t) (2*image->columns),scanline);
+            count=ReadBlob(image,(size_t) (2*quantum*image->columns),scanline);
           p=scanline;
           q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
           if (q == (PixelPacket *) NULL)
@@ -239,16 +238,44 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
             break;
           for (x=0; x < (ssize_t) image->columns; x+=2)
           {
-            chroma_pixels->red=(Quantum) 0;
-            chroma_pixels->green=ScaleCharToQuantum(*p++);
-            q->red=ScaleCharToQuantum(*p++);
-            q->green=(Quantum) 0;
-            q->blue=(Quantum) 0;
+            SetPixelRed(chroma_pixels,0);
+            if (quantum == 1)
+              SetPixelGreen(chroma_pixels,ScaleCharToQuantum(*p++));
+            else
+              {
+                SetPixelGreen(chroma_pixels,ScaleShortToQuantum(
+                  ((*p) << 8) | *(p+1)));
+                p+=2;
+              }
+            if (quantum == 1)
+              SetPixelRed(q,ScaleCharToQuantum(*p++));
+            else
+              {
+                SetPixelRed(q,ScaleShortToQuantum(((*p) << 8) |
+                  *(p+1)));
+                p+=2;
+              }
+            SetPixelGreen(q,0);
+            SetPixelBlue(q,0);
             q++;
-            q->green=0;
-            q->blue=0;
-            chroma_pixels->blue=ScaleCharToQuantum(*p++);
-            q->red=ScaleCharToQuantum(*p++);
+            SetPixelGreen(q,0);
+            SetPixelBlue(q,0);
+            if (quantum == 1)
+              SetPixelBlue(chroma_pixels,ScaleCharToQuantum(*p++));
+            else
+              {
+                SetPixelBlue(chroma_pixels,ScaleShortToQuantum(
+                  ((*p) << 8) | *(p+1)));
+                p+=2;
+              }
+            if (quantum == 1)
+              SetPixelRed(q,ScaleCharToQuantum(*p++));
+            else
+              {
+                SetPixelRed(q,ScaleShortToQuantum(((*p) << 8) |
+                  *(p+1)));
+                p+=2;
+              }
             chroma_pixels++;
             q++;
           }
@@ -256,16 +283,23 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
       else
         {
           if ((y > 0) || (GetPreviousImageInList(image) == (Image *) NULL))
-            count=ReadBlob(image,(size_t) image->columns,scanline);
+            count=ReadBlob(image,(size_t) quantum*image->columns,scanline);
           p=scanline;
           q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
           if (q == (PixelPacket *) NULL)
             break;
           for (x=0; x < (ssize_t) image->columns; x++)
           {
-            q->red=ScaleCharToQuantum(*p++);
-            q->green=0;
-            q->blue=0;
+            if (quantum == 1)
+              SetPixelRed(q,ScaleCharToQuantum(*p++));
+            else
+              {
+                SetPixelRed(q,ScaleShortToQuantum(((*p) << 8) |
+                  *(p+1)));
+                p+=2;
+              }
+            SetPixelGreen(q,0);
+            SetPixelBlue(q,0);
             q++;
           }
         }
@@ -277,7 +311,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
       if (image->previous == (Image *) NULL)
         {
           status=SetImageProgress(image,LoadImageTag,(MagickOffsetType) y,
-                image->rows);
+            image->rows);
           if (status == MagickFalse)
             break;
         }
@@ -297,7 +331,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
       {
         for (y=0; y < (ssize_t) chroma_image->rows; y++)
         {
-          count=ReadBlob(image,(size_t) chroma_image->columns,scanline);
+          count=ReadBlob(image,(size_t) quantum*chroma_image->columns,scanline);
           p=scanline;
           q=QueueAuthenticPixels(chroma_image,0,y,chroma_image->columns,1,
             exception);
@@ -305,9 +339,16 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
             break;
           for (x=0; x < (ssize_t) chroma_image->columns; x++)
           {
-            q->red=(Quantum) 0;
-            q->green=ScaleCharToQuantum(*p++);
-            q->blue=(Quantum) 0;
+            SetPixelRed(q,0);
+            if (quantum == 1)
+              SetPixelGreen(q,ScaleCharToQuantum(*p++));
+            else
+              {
+                SetPixelGreen(q,ScaleShortToQuantum(((*p) << 8) |
+                  *(p+1)));
+                p+=2;
+              }
+            SetPixelBlue(q,0);
             q++;
           }
           if (SyncAuthenticPixels(chroma_image,exception) == MagickFalse)
@@ -326,7 +367,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
         }
       for (y=0; y < (ssize_t) chroma_image->rows; y++)
       {
-        count=ReadBlob(image,(size_t) chroma_image->columns,scanline);
+        count=ReadBlob(image,(size_t) quantum*chroma_image->columns,scanline);
         p=scanline;
         q=GetAuthenticPixels(chroma_image,0,y,chroma_image->columns,1,
           exception);
@@ -334,7 +375,14 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
           break;
         for (x=0; x < (ssize_t) chroma_image->columns; x++)
         {
-          q->blue=ScaleCharToQuantum(*p++);
+          if (quantum == 1)
+            SetPixelBlue(q,ScaleCharToQuantum(*p++));
+          else
+            {
+              SetPixelBlue(q,ScaleShortToQuantum(((*p) << 8) |
+                *(p+1)));
+              p+=2;
+            }
           q++;
         }
         if (SyncAuthenticPixels(chroma_image,exception) == MagickFalse)
@@ -359,8 +407,8 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
         break;
       for (x=0; x < (ssize_t) image->columns; x++)
       {
-        q->green=chroma_pixels->green;
-        q->blue=chroma_pixels->blue;
+        SetPixelGreen(q,GetPixelGreen(chroma_pixels));
+        SetPixelBlue(q,GetPixelBlue(chroma_pixels));
         chroma_pixels++;
         q++;
       }
@@ -385,9 +433,9 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
     if (interlace == NoInterlace)
-      count=ReadBlob(image,(size_t) (2*image->columns),scanline);
+      count=ReadBlob(image,(size_t) (2*quantum*image->columns),scanline);
     else
-      count=ReadBlob(image,(size_t) image->columns,scanline);
+      count=ReadBlob(image,(size_t) quantum*image->columns,scanline);
     if (count != 0)
       {
         /*
@@ -509,11 +557,6 @@ static MagickBooleanType WriteYUVImage(const ImageInfo *image_info,Image *image)
   InterlaceType
     interlace;
 
-  ssize_t
-    horizontal_factor,
-    vertical_factor,
-    y;
-
   MagickBooleanType
     status;
 
@@ -529,14 +572,21 @@ static MagickBooleanType WriteYUVImage(const ImageInfo *image_info,Image *image)
 
   size_t
     height,
+    quantum,
     width;
 
+  ssize_t
+    horizontal_factor,
+    vertical_factor,
+    y;
+
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
+  quantum=image->depth <= 8 ? 1 : 2;
   interlace=image->interlace;
   horizontal_factor=2;
   vertical_factor=2;
@@ -586,7 +636,7 @@ static MagickBooleanType WriteYUVImage(const ImageInfo *image_info,Image *image)
     /*
       Sample image to an even width and height, if necessary.
     */
-    image->depth=8;
+    image->depth=quantum == 1 ? 8 : 16;
     width=image->columns+(image->columns & (horizontal_factor-1));
     height=image->rows+(image->rows & (vertical_factor-1));
     yuv_image=ResizeImage(image,width,height,TriangleFilter,1.0,
@@ -619,11 +669,30 @@ static MagickBooleanType WriteYUVImage(const ImageInfo *image_info,Image *image)
             break;
           for (x=0; x < (ssize_t) yuv_image->columns; x++)
           {
-            (void) WriteBlobByte(image,ScaleQuantumToChar(s->green));
-            (void) WriteBlobByte(image,ScaleQuantumToChar(GetRedPixelComponent(p)));
-            p++;
-            (void) WriteBlobByte(image,ScaleQuantumToChar(s->blue));
-            (void) WriteBlobByte(image,ScaleQuantumToChar(GetRedPixelComponent(p)));
+            if (quantum == 1)
+              {
+                (void) WriteBlobByte(image,ScaleQuantumToChar(
+                  GetPixelGreen(s)));
+                (void) WriteBlobByte(image,ScaleQuantumToChar(
+                  GetPixelRed(p)));
+                p++;
+                (void) WriteBlobByte(image,ScaleQuantumToChar(
+                  GetPixelBlue(s)));
+                (void) WriteBlobByte(image,ScaleQuantumToChar(
+                  GetPixelRed(p)));
+              }
+            else
+              {
+                (void) WriteBlobByte(image,ScaleQuantumToChar(
+                  GetPixelGreen(s)));
+                (void) WriteBlobShort(image,ScaleQuantumToShort(
+                  GetPixelRed(p)));
+                p++;
+                (void) WriteBlobByte(image,ScaleQuantumToChar(
+                  GetPixelBlue(s)));
+                (void) WriteBlobShort(image,ScaleQuantumToShort(
+                  GetPixelRed(p)));
+              }
             p++;
             s++;
             x++;
@@ -651,7 +720,12 @@ static MagickBooleanType WriteYUVImage(const ImageInfo *image_info,Image *image)
             break;
           for (x=0; x < (ssize_t) yuv_image->columns; x++)
           {
-            (void) WriteBlobByte(image,ScaleQuantumToChar(GetRedPixelComponent(p)));
+            if (quantum == 1)
+              (void) WriteBlobByte(image,ScaleQuantumToChar(
+                GetPixelRed(p)));
+            else
+              (void) WriteBlobShort(image,ScaleQuantumToShort(
+                GetPixelRed(p)));
             p++;
           }
           if (image->previous == (Image *) NULL)
@@ -689,7 +763,12 @@ static MagickBooleanType WriteYUVImage(const ImageInfo *image_info,Image *image)
             break;
           for (x=0; x < (ssize_t) chroma_image->columns; x++)
           {
-            (void) WriteBlobByte(image,ScaleQuantumToChar(GetGreenPixelComponent(p)));
+            if (quantum == 1)
+              (void) WriteBlobByte(image,ScaleQuantumToChar(
+                GetPixelGreen(p)));
+            else
+              (void) WriteBlobShort(image,ScaleQuantumToShort(
+                GetPixelGreen(p)));
             p++;
           }
         }
@@ -719,7 +798,12 @@ static MagickBooleanType WriteYUVImage(const ImageInfo *image_info,Image *image)
             break;
           for (x=0; x < (ssize_t) chroma_image->columns; x++)
           {
-            (void) WriteBlobByte(image,ScaleQuantumToChar(GetBluePixelComponent(p)));
+            if (quantum == 1)
+              (void) WriteBlobByte(image,ScaleQuantumToChar(
+                GetPixelBlue(p)));
+            else
+              (void) WriteBlobShort(image,ScaleQuantumToShort(
+                GetPixelBlue(p)));
             p++;
           }
         }
