@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -55,8 +55,9 @@ extern "C" {
 #  define MAGICKCORE_POSIX_SUPPORT
 #endif 
 
-#if defined(MAGICKCORE_WINDOWS_SUPPORT) && !defined(__CYGWIN__) && !defined(__MINGW32__)
-# if defined(_MT) && defined(_DLL) && !defined(_MAGICKDLL_) && !defined(_LIB) && !defined(MAGICK_STATIC_LINK)
+#if defined(MAGICKCORE_WINDOWS_SUPPORT) || defined(__CYGWIN__) || defined(__MINGW32__)
+# define MagickPrivate
+# if defined(_MT) && defined(_DLL) && !defined(_MAGICKDLL_) && !defined(_LIB)
 #  define _MAGICKDLL_
 # endif
 # if defined(_MAGICKDLL_)
@@ -64,38 +65,51 @@ extern "C" {
 #   pragma warning( disable: 4273 )  /* Disable the dll linkage warnings */
 #  endif
 #  if !defined(_MAGICKLIB_)
-#   define MagickExport  __declspec(dllimport)
+#   if defined(__GNUC__)
+#    define MagickExport __attribute__ ((dllimport))
+#   else
+#    define MagickExport __declspec(dllimport)
+#   endif
 #   if defined(_VISUALC_)
-#    pragma message( "Magick lib DLL import interface" )
+#    pragma message( "MagickCore lib DLL import interface" )
 #   endif
 #  else
-#   define MagickExport  __declspec(dllexport)
+#   if defined(__GNUC__)
+#    define MagickExport __attribute__ ((dllexport))
+#   else
+#    define MagickExport __declspec(dllexport)
+#   endif
 #   if defined(_VISUALC_)
-#    pragma message( "Magick lib DLL export interface" )
+#    pragma message( "MagickCore lib DLL export interface" )
 #   endif
 #  endif
 # else
 #  define MagickExport
 #  if defined(_VISUALC_)
-#   pragma message( "Magick lib static interface" )
+#   pragma message( "MagickCore lib static interface" )
 #  endif
 # endif
 
 # if defined(_DLL) && !defined(_LIB)
-#  define ModuleExport  __declspec(dllexport)
+#   if defined(__GNUC__)
+#    define ModuleExport __attribute__ ((dllexport))
+#   else
+#    define ModuleExport __declspec(dllexport)
+#   endif
 #  if defined(_VISUALC_)
-#   pragma message( "Magick module DLL export interface" )
+#   pragma message( "MagickCore module DLL export interface" )
 #  endif
 # else
 #  define ModuleExport
 #  if defined(_VISUALC_)
-#   pragma message( "Magick module static interface" )
+#   pragma message( "MagickCore module static interface" )
 #  endif
 
 # endif
 # define MagickGlobal __declspec(thread)
 # if defined(_VISUALC_)
 #  pragma warning(disable : 4018)
+#  pragma warning(disable : 4068)
 #  pragma warning(disable : 4244)
 #  pragma warning(disable : 4142)
 #  pragma warning(disable : 4800)
@@ -103,8 +117,14 @@ extern "C" {
 #  pragma warning(disable : 4996)
 # endif
 #else
-# define MagickExport
-# define ModuleExport
+# if __GNUC__ >= 4
+#  define MagickExport __attribute__ ((visibility ("default")))
+#  define MagickPrivate  __attribute__ ((visibility ("hidden")))
+# else
+#   define MagickExport
+#   define MagickPrivate
+# endif
+# define ModuleExport  MagickExport
 # define MagickGlobal
 #endif
 
