@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -235,8 +235,11 @@ extern MagickExport PixelPacket
   *GetAuthenticPixelCacheNexus(Image *,const ssize_t,const ssize_t,
     const size_t,const size_t,NexusInfo *,ExceptionInfo *),
   *GetPixelCacheNexusPixels(const Cache,NexusInfo *),
-  *QueueAuthenticNexus(Image *,const ssize_t,const ssize_t,const size_t,
-    const size_t,NexusInfo *,ExceptionInfo *);
+  *QueueAuthenticPixel(Image *,const ssize_t,const ssize_t,const size_t,
+    const size_t,const MagickBooleanType,NexusInfo *,ExceptionInfo *),
+  *QueueAuthenticPixelCacheNexus(Image *,const ssize_t,const ssize_t,
+    const size_t,const size_t,const MagickBooleanType,NexusInfo *,
+    ExceptionInfo *);
 
 extern MagickExport size_t
   GetPixelCacheChannels(const Cache);
