@@ -17,7 +17,7 @@
 %                               December 2003                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -110,8 +110,8 @@ MagickExport Image *CompareImages(Image *image,const Image *reconstruct_image,
   Image
     *highlight_image;
 
-  highlight_image=CompareImageChannels(image,reconstruct_image,CompositeChannels,
-    metric,distortion,exception);
+  highlight_image=CompareImageChannels(image,reconstruct_image,
+    CompositeChannels,metric,distortion,exception);
   return(highlight_image);
 }
 
@@ -131,9 +131,6 @@ MagickExport Image *CompareImageChannels(Image *image,
     *difference_image,
     *highlight_image;
 
-  ssize_t
-    y;
-
   MagickBooleanType
     status;
 
@@ -142,6 +139,9 @@ MagickExport Image *CompareImageChannels(Image *image,
     lowlight,
     zero;
 
+  ssize_t
+    y;
+
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
@@ -200,7 +200,7 @@ MagickExport Image *CompareImageChannels(Image *image,
   reconstruct_view=AcquireCacheView(reconstruct_image);
   highlight_view=AcquireCacheView(highlight_image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(dynamic,4) shared(status)
+  #pragma omp parallel for schedule(static,4) shared(status)
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
   {
@@ -222,12 +222,12 @@ MagickExport Image *CompareImageChannels(Image *image,
     register IndexPacket
       *restrict highlight_indexes;
 
-    register ssize_t
-      x;
-
     register PixelPacket
       *restrict r;
 
+    register ssize_t
+      x;
+
     if (status == MagickFalse)
       continue;
     p=GetCacheViewVirtualPixels(image_view,0,y,image->columns,1,exception);
@@ -263,23 +263,23 @@ MagickExport Image *CompareImageChannels(Image *image,
       else
         {
           if (((channel & RedChannel) != 0) &&
-              (GetRedPixelComponent(p) != GetRedPixelComponent(q)))
+              (GetPixelRed(p) != GetPixelRed(q)))
             difference=MagickTrue;
           if (((channel & GreenChannel) != 0) &&
-              (GetGreenPixelComponent(p) != GetGreenPixelComponent(q)))
+              (GetPixelGreen(p) != GetPixelGreen(q)))
             difference=MagickTrue;
           if (((channel & BlueChannel) != 0) &&
-              (GetBluePixelComponent(p) != GetBluePixelComponent(q)))
+              (GetPixelBlue(p) != GetPixelBlue(q)))
             difference=MagickTrue;
           if (((channel & OpacityChannel) != 0) &&
               (image->matte != MagickFalse) &&
-              (GetOpacityPixelComponent(p) != GetOpacityPixelComponent(q)))
+              (GetPixelOpacity(p) != GetPixelOpacity(q)))
             difference=MagickTrue;
           if ((((channel & IndexChannel) != 0) &&
                (image->colorspace == CMYKColorspace) &&
                (reconstruct_image->colorspace == CMYKColorspace)) &&
-              (GetIndexPixelComponent(indexes+x) !=
-               GetIndexPixelComponent(reconstruct_indexes+x)))
+              (GetPixelIndex(indexes+x) !=
+               GetPixelIndex(reconstruct_indexes+x)))
             difference=MagickTrue;
         }
       if (difference != MagickFalse)
@@ -377,7 +377,7 @@ static MagickBooleanType GetAbsoluteDistortion(const Image *image,
   image_view=AcquireCacheView(image);
   reconstruct_view=AcquireCacheView(reconstruct_image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(dynamic,4) shared(status)
+  #pragma omp parallel for schedule(static,4) shared(status)
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
   {
@@ -493,7 +493,7 @@ static MagickBooleanType GetFuzzDistortion(const Image *image,
   image_view=AcquireCacheView(image);
   reconstruct_view=AcquireCacheView(reconstruct_image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(dynamic,4) shared(status)
+  #pragma omp parallel for schedule(static,4) shared(status)
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
   {
@@ -532,22 +532,22 @@ static MagickBooleanType GetFuzzDistortion(const Image *image,
 
       if ((channel & RedChannel) != 0)
         {
-          distance=QuantumScale*(GetRedPixelComponent(p)-(MagickRealType)
-            GetRedPixelComponent(q));
+          distance=QuantumScale*(GetPixelRed(p)-(MagickRealType)
+            GetPixelRed(q));
           channel_distortion[RedChannel]+=distance*distance;
           channel_distortion[CompositeChannels]+=distance*distance;
         }
       if ((channel & GreenChannel) != 0)
         {
-          distance=QuantumScale*(GetGreenPixelComponent(p)-(MagickRealType)
-            GetGreenPixelComponent(q));
+          distance=QuantumScale*(GetPixelGreen(p)-(MagickRealType)
+            GetPixelGreen(q));
           channel_distortion[GreenChannel]+=distance*distance;
           channel_distortion[CompositeChannels]+=distance*distance;
         }
       if ((channel & BlueChannel) != 0)
         {
-          distance=QuantumScale*(GetBluePixelComponent(p)-(MagickRealType)
-            GetBluePixelComponent(q));
+          distance=QuantumScale*(GetPixelBlue(p)-(MagickRealType)
+            GetPixelBlue(q));
           channel_distortion[BlueChannel]+=distance*distance;
           channel_distortion[CompositeChannels]+=distance*distance;
         }
@@ -555,9 +555,9 @@ static MagickBooleanType GetFuzzDistortion(const Image *image,
           (reconstruct_image->matte != MagickFalse)))
         {
           distance=QuantumScale*((image->matte != MagickFalse ?
-            GetOpacityPixelComponent(p) : OpaqueOpacity)-
+            GetPixelOpacity(p) : OpaqueOpacity)-
             (reconstruct_image->matte != MagickFalse ?
-            GetOpacityPixelComponent(q): OpaqueOpacity));
+            GetPixelOpacity(q): OpaqueOpacity));
           channel_distortion[OpacityChannel]+=distance*distance;
           channel_distortion[CompositeChannels]+=distance*distance;
         }
@@ -565,8 +565,8 @@ static MagickBooleanType GetFuzzDistortion(const Image *image,
           (image->colorspace == CMYKColorspace) &&
           (reconstruct_image->colorspace == CMYKColorspace))
         {
-          distance=QuantumScale*(GetIndexPixelComponent(indexes+x)-
-            (MagickRealType) GetIndexPixelComponent(reconstruct_indexes+x));
+          distance=QuantumScale*(GetPixelIndex(indexes+x)-
+            (MagickRealType) GetPixelIndex(reconstruct_indexes+x));
           channel_distortion[BlackChannel]+=distance*distance;
           channel_distortion[CompositeChannels]+=distance*distance;
         }
@@ -613,7 +613,7 @@ static MagickBooleanType GetMeanAbsoluteDistortion(const Image *image,
   image_view=AcquireCacheView(image);
   reconstruct_view=AcquireCacheView(reconstruct_image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(dynamic,4) shared(status)
+  #pragma omp parallel for schedule(static,4) shared(status)
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
   {
@@ -652,38 +652,38 @@ static MagickBooleanType GetMeanAbsoluteDistortion(const Image *image,
 
       if ((channel & RedChannel) != 0)
         {
-          distance=QuantumScale*fabs(GetRedPixelComponent(p)-(double)
-            GetRedPixelComponent(q));
+          distance=QuantumScale*fabs(GetPixelRed(p)-(double)
+            GetPixelRed(q));
           channel_distortion[RedChannel]+=distance;
           channel_distortion[CompositeChannels]+=distance;
         }
       if ((channel & GreenChannel) != 0)
         {
-          distance=QuantumScale*fabs(GetGreenPixelComponent(p)-(double)
-            GetGreenPixelComponent(q));
+          distance=QuantumScale*fabs(GetPixelGreen(p)-(double)
+            GetPixelGreen(q));
           channel_distortion[GreenChannel]+=distance;
           channel_distortion[CompositeChannels]+=distance;
         }
       if ((channel & BlueChannel) != 0)
         {
-          distance=QuantumScale*fabs(GetBluePixelComponent(p)-(double)
-            GetBluePixelComponent(q));
+          distance=QuantumScale*fabs(GetPixelBlue(p)-(double)
+            GetPixelBlue(q));
           channel_distortion[BlueChannel]+=distance;
           channel_distortion[CompositeChannels]+=distance;
         }
       if (((channel & OpacityChannel) != 0) &&
           (image->matte != MagickFalse))
         {
-          distance=QuantumScale*fabs(GetOpacityPixelComponent(p)-(double)
-            GetOpacityPixelComponent(q));
+          distance=QuantumScale*fabs(GetPixelOpacity(p)-(double)
+            GetPixelOpacity(q));
           channel_distortion[OpacityChannel]+=distance;
           channel_distortion[CompositeChannels]+=distance;
         }
       if (((channel & IndexChannel) != 0) &&
           (image->colorspace == CMYKColorspace))
         {
-          distance=QuantumScale*fabs(GetIndexPixelComponent(indexes+x)-(double)
-            GetIndexPixelComponent(reconstruct_indexes+x));
+          distance=QuantumScale*fabs(GetPixelIndex(indexes+x)-(double)
+            GetPixelIndex(reconstruct_indexes+x));
           channel_distortion[BlackChannel]+=distance;
           channel_distortion[CompositeChannels]+=distance;
         }
@@ -764,14 +764,14 @@ static MagickBooleanType GetMeanErrorPerPixel(Image *image,
       if ((channel & OpacityChannel) != 0)
         {
           if (image->matte != MagickFalse)
-            alpha=(MagickRealType) (QuantumScale*(GetAlphaPixelComponent(p)));
+            alpha=(MagickRealType) (QuantumScale*(GetPixelAlpha(p)));
           if (reconstruct_image->matte != MagickFalse)
-            beta=(MagickRealType) (QuantumScale*GetAlphaPixelComponent(q));
+            beta=(MagickRealType) (QuantumScale*GetPixelAlpha(q));
         }
       if ((channel & RedChannel) != 0)
         {
-          distance=fabs(alpha*GetRedPixelComponent(p)-beta*
-            GetRedPixelComponent(q));
+          distance=fabs(alpha*GetPixelRed(p)-beta*
+            GetPixelRed(q));
           distortion[RedChannel]+=distance;
           distortion[CompositeChannels]+=distance;
           mean_error+=distance*distance;
@@ -781,8 +781,8 @@ static MagickBooleanType GetMeanErrorPerPixel(Image *image,
         }
       if ((channel & GreenChannel) != 0)
         {
-          distance=fabs(alpha*GetGreenPixelComponent(p)-beta*
-            GetGreenPixelComponent(q));
+          distance=fabs(alpha*GetPixelGreen(p)-beta*
+            GetPixelGreen(q));
           distortion[GreenChannel]+=distance;
           distortion[CompositeChannels]+=distance;
           mean_error+=distance*distance;
@@ -792,8 +792,8 @@ static MagickBooleanType GetMeanErrorPerPixel(Image *image,
         }
       if ((channel & BlueChannel) != 0)
         {
-          distance=fabs(alpha*GetBluePixelComponent(p)-beta*
-            GetBluePixelComponent(q));
+          distance=fabs(alpha*GetPixelBlue(p)-beta*
+            GetPixelBlue(q));
           distortion[BlueChannel]+=distance;
           distortion[CompositeChannels]+=distance;
           mean_error+=distance*distance;
@@ -804,8 +804,8 @@ static MagickBooleanType GetMeanErrorPerPixel(Image *image,
       if (((channel & OpacityChannel) != 0) &&
           (image->matte != MagickFalse))
         {
-          distance=fabs((double) GetOpacityPixelComponent(p)-
-            GetOpacityPixelComponent(q));
+          distance=fabs((double) GetPixelOpacity(p)-
+            GetPixelOpacity(q));
           distortion[OpacityChannel]+=distance;
           distortion[CompositeChannels]+=distance;
           mean_error+=distance*distance;
@@ -817,8 +817,8 @@ static MagickBooleanType GetMeanErrorPerPixel(Image *image,
           (image->colorspace == CMYKColorspace) &&
           (reconstruct_image->colorspace == CMYKColorspace))
         {
-          distance=fabs(alpha*GetIndexPixelComponent(indexes+x)-beta*
-            GetIndexPixelComponent(reconstruct_indexes+x));
+          distance=fabs(alpha*GetPixelIndex(indexes+x)-beta*
+            GetPixelIndex(reconstruct_indexes+x));
           distortion[BlackChannel]+=distance;
           distortion[CompositeChannels]+=distance;
           mean_error+=distance*distance;
@@ -859,7 +859,7 @@ static MagickBooleanType GetMeanSquaredDistortion(const Image *image,
   image_view=AcquireCacheView(image);
   reconstruct_view=AcquireCacheView(reconstruct_image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(dynamic,4) shared(status)
+  #pragma omp parallel for schedule(static,4) shared(status)
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
   {
@@ -898,30 +898,30 @@ static MagickBooleanType GetMeanSquaredDistortion(const Image *image,
 
       if ((channel & RedChannel) != 0)
         {
-          distance=QuantumScale*(GetRedPixelComponent(p)-(MagickRealType)
-            GetRedPixelComponent(q));
+          distance=QuantumScale*(GetPixelRed(p)-(MagickRealType)
+            GetPixelRed(q));
           channel_distortion[RedChannel]+=distance*distance;
           channel_distortion[CompositeChannels]+=distance*distance;
         }
       if ((channel & GreenChannel) != 0)
         {
-          distance=QuantumScale*(GetGreenPixelComponent(p)-(MagickRealType)
-            GetGreenPixelComponent(q));
+          distance=QuantumScale*(GetPixelGreen(p)-(MagickRealType)
+            GetPixelGreen(q));
           channel_distortion[GreenChannel]+=distance*distance;
           channel_distortion[CompositeChannels]+=distance*distance;
         }
       if ((channel & BlueChannel) != 0)
         {
-          distance=QuantumScale*(GetBluePixelComponent(p)-(MagickRealType)
-            GetBluePixelComponent(q));
+          distance=QuantumScale*(GetPixelBlue(p)-(MagickRealType)
+            GetPixelBlue(q));
           channel_distortion[BlueChannel]+=distance*distance;
           channel_distortion[CompositeChannels]+=distance*distance;
         }
       if (((channel & OpacityChannel) != 0) &&
           (image->matte != MagickFalse))
         {
-          distance=QuantumScale*(GetOpacityPixelComponent(p)-(MagickRealType)
-            GetOpacityPixelComponent(q));
+          distance=QuantumScale*(GetPixelOpacity(p)-(MagickRealType)
+            GetPixelOpacity(q));
           channel_distortion[OpacityChannel]+=distance*distance;
           channel_distortion[CompositeChannels]+=distance*distance;
         }
@@ -929,8 +929,8 @@ static MagickBooleanType GetMeanSquaredDistortion(const Image *image,
           (image->colorspace == CMYKColorspace) &&
           (reconstruct_image->colorspace == CMYKColorspace))
         {
-          distance=QuantumScale*(GetIndexPixelComponent(indexes+x)-
-            (MagickRealType) GetIndexPixelComponent(reconstruct_indexes+x));
+          distance=QuantumScale*(GetPixelIndex(indexes+x)-
+            (MagickRealType) GetPixelIndex(reconstruct_indexes+x));
           channel_distortion[BlackChannel]+=distance*distance;
           channel_distortion[CompositeChannels]+=distance*distance;
         }
@@ -989,7 +989,7 @@ static MagickBooleanType GetNormalizedCrossCorrelationDistortion(
   progress=0;
   for (i=0; i <= (ssize_t) CompositeChannels; i++)
     distortion[i]=0.0;
-  area=1.0/((MagickRealType) image->columns*image->rows);
+  area=1.0/((MagickRealType) image->columns*image->rows-1);
   image_view=AcquireCacheView(image);
   reconstruct_view=AcquireCacheView(reconstruct_image);
   for (y=0; y < (ssize_t) image->rows; y++)
@@ -1020,30 +1020,30 @@ static MagickBooleanType GetNormalizedCrossCorrelationDistortion(
     for (x=0; x < (ssize_t) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
-        distortion[RedChannel]+=area*QuantumScale*(GetRedPixelComponent(p)-
-          image_statistics[RedChannel].mean)*(GetRedPixelComponent(q)-
+        distortion[RedChannel]+=area*QuantumScale*(GetPixelRed(p)-
+          image_statistics[RedChannel].mean)*(GetPixelRed(q)-
           reconstruct_statistics[RedChannel].mean);
       if ((channel & GreenChannel) != 0)
-        distortion[GreenChannel]+=area*QuantumScale*(GetGreenPixelComponent(p)-
-          image_statistics[GreenChannel].mean)*(GetGreenPixelComponent(q)-
+        distortion[GreenChannel]+=area*QuantumScale*(GetPixelGreen(p)-
+          image_statistics[GreenChannel].mean)*(GetPixelGreen(q)-
           reconstruct_statistics[GreenChannel].mean);
       if ((channel & BlueChannel) != 0)
-        distortion[BlueChannel]+=area*QuantumScale*(GetBluePixelComponent(p)-
-          image_statistics[BlueChannel].mean)*(GetBluePixelComponent(q)-
+        distortion[BlueChannel]+=area*QuantumScale*(GetPixelBlue(p)-
+          image_statistics[BlueChannel].mean)*(GetPixelBlue(q)-
           reconstruct_statistics[BlueChannel].mean);
       if (((channel & OpacityChannel) != 0) &&
           (image->matte != MagickFalse))
         distortion[OpacityChannel]+=area*QuantumScale*(
-          GetOpacityPixelComponent(p)-image_statistics[OpacityChannel].mean)*
-          (GetOpacityPixelComponent(q)-
+          GetPixelOpacity(p)-image_statistics[OpacityChannel].mean)*
+          (GetPixelOpacity(q)-
           reconstruct_statistics[OpacityChannel].mean);
       if (((channel & IndexChannel) != 0) &&
           (image->colorspace == CMYKColorspace) &&
           (reconstruct_image->colorspace == CMYKColorspace))
         distortion[BlackChannel]+=area*QuantumScale*(
-          GetIndexPixelComponent(indexes+x)-
+          GetPixelIndex(indexes+x)-
           image_statistics[OpacityChannel].mean)*(
-          GetIndexPixelComponent(reconstruct_indexes+x)-
+          GetPixelIndex(reconstruct_indexes+x)-
           reconstruct_statistics[OpacityChannel].mean);
       p++;
       q++;
@@ -1121,7 +1121,7 @@ static MagickBooleanType GetPeakAbsoluteDistortion(const Image *image,
   image_view=AcquireCacheView(image);
   reconstruct_view=AcquireCacheView(reconstruct_image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(dynamic,4) shared(status)
+  #pragma omp parallel for schedule(static,4) shared(status)
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
   {
@@ -1160,8 +1160,8 @@ static MagickBooleanType GetPeakAbsoluteDistortion(const Image *image,
 
       if ((channel & RedChannel) != 0)
         {
-          distance=QuantumScale*fabs(GetRedPixelComponent(p)-(double)
-            GetRedPixelComponent(q));
+          distance=QuantumScale*fabs(GetPixelRed(p)-(double)
+            GetPixelRed(q));
           if (distance > channel_distortion[RedChannel])
             channel_distortion[RedChannel]=distance;
           if (distance > channel_distortion[CompositeChannels])
@@ -1169,8 +1169,8 @@ static MagickBooleanType GetPeakAbsoluteDistortion(const Image *image,
         }
       if ((channel & GreenChannel) != 0)
         {
-          distance=QuantumScale*fabs(GetGreenPixelComponent(p)-(double)
-            GetGreenPixelComponent(q));
+          distance=QuantumScale*fabs(GetPixelGreen(p)-(double)
+            GetPixelGreen(q));
           if (distance > channel_distortion[GreenChannel])
             channel_distortion[GreenChannel]=distance;
           if (distance > channel_distortion[CompositeChannels])
@@ -1178,8 +1178,8 @@ static MagickBooleanType GetPeakAbsoluteDistortion(const Image *image,
         }
       if ((channel & BlueChannel) != 0)
         {
-          distance=QuantumScale*fabs(GetBluePixelComponent(p)-(double)
-            GetBluePixelComponent(q));
+          distance=QuantumScale*fabs(GetPixelBlue(p)-(double)
+            GetPixelBlue(q));
           if (distance > channel_distortion[BlueChannel])
             channel_distortion[BlueChannel]=distance;
           if (distance > channel_distortion[CompositeChannels])
@@ -1188,8 +1188,8 @@ static MagickBooleanType GetPeakAbsoluteDistortion(const Image *image,
       if (((channel & OpacityChannel) != 0) &&
           (image->matte != MagickFalse))
         {
-          distance=QuantumScale*fabs(GetOpacityPixelComponent(p)-(double)
-            GetOpacityPixelComponent(q));
+          distance=QuantumScale*fabs(GetPixelOpacity(p)-(double)
+            GetPixelOpacity(q));
           if (distance > channel_distortion[OpacityChannel])
             channel_distortion[OpacityChannel]=distance;
           if (distance > channel_distortion[CompositeChannels])
@@ -1199,8 +1199,8 @@ static MagickBooleanType GetPeakAbsoluteDistortion(const Image *image,
           (image->colorspace == CMYKColorspace) &&
           (reconstruct_image->colorspace == CMYKColorspace))
         {
-          distance=QuantumScale*fabs(GetIndexPixelComponent(indexes+x)-(double)
-            GetIndexPixelComponent(reconstruct_indexes+x));
+          distance=QuantumScale*fabs(GetPixelIndex(indexes+x)-(double)
+            GetPixelIndex(reconstruct_indexes+x));
           if (distance > channel_distortion[BlackChannel])
             channel_distortion[BlackChannel]=distance;
           if (distance > channel_distortion[CompositeChannels])
@@ -1621,22 +1621,22 @@ MagickExport MagickBooleanType IsImagesEqual(Image *image,
       MagickRealType
         distance;
 
-      distance=fabs(GetRedPixelComponent(p)-(double)
-        GetRedPixelComponent(q));
+      distance=fabs(GetPixelRed(p)-(double)
+        GetPixelRed(q));
       mean_error_per_pixel+=distance;
       mean_error+=distance*distance;
       if (distance > maximum_error)
         maximum_error=distance;
       area++;
-      distance=fabs(GetGreenPixelComponent(p)-(double)
-        GetGreenPixelComponent(q));
+      distance=fabs(GetPixelGreen(p)-(double)
+        GetPixelGreen(q));
       mean_error_per_pixel+=distance;
       mean_error+=distance*distance;
       if (distance > maximum_error)
         maximum_error=distance;
       area++;
-      distance=fabs(GetBluePixelComponent(p)-(double)
-        GetBluePixelComponent(q));
+      distance=fabs(GetPixelBlue(p)-(double)
+        GetPixelBlue(q));
       mean_error_per_pixel+=distance;
       mean_error+=distance*distance;
       if (distance > maximum_error)
@@ -1644,8 +1644,8 @@ MagickExport MagickBooleanType IsImagesEqual(Image *image,
       area++;
       if (image->matte != MagickFalse)
         {
-          distance=fabs(GetOpacityPixelComponent(p)-(double)
-            GetOpacityPixelComponent(q));
+          distance=fabs(GetPixelOpacity(p)-(double)
+            GetPixelOpacity(q));
           mean_error_per_pixel+=distance;
           mean_error+=distance*distance;
           if (distance > maximum_error)
@@ -1655,8 +1655,8 @@ MagickExport MagickBooleanType IsImagesEqual(Image *image,
       if ((image->colorspace == CMYKColorspace) &&
           (reconstruct_image->colorspace == CMYKColorspace))
         {
-          distance=fabs(GetIndexPixelComponent(indexes+x)-(double)
-            GetIndexPixelComponent(reconstruct_indexes+x));
+          distance=fabs(GetPixelIndex(indexes+x)-(double)
+            GetPixelIndex(reconstruct_indexes+x));
           mean_error_per_pixel+=distance;
           mean_error+=distance*distance;
           if (distance > maximum_error)
@@ -1712,119 +1712,9 @@ MagickExport MagickBooleanType IsImagesEqual(Image *image,
 %
 */
 
-static double GetNCCDistortion(const Image *image,
-  const Image *reconstruct_image,
-  const ChannelStatistics *reconstruct_statistics,ExceptionInfo *exception)
-{
-#define SimilarityImageTag  "Similarity/Image"
-
-  CacheView
-    *image_view,
-    *reconstruct_view;
-
-  ChannelStatistics
-    *image_statistics;
-
-  double
-    distortion;
-
-  MagickBooleanType
-    status;
-
-  MagickRealType
-    area,
-    gamma;
-
-  ssize_t
-    y;
-
-  unsigned long
-    number_channels;
-  
-  /*
-    Normalize to account for variation due to lighting and exposure condition.
-  */
-  image_statistics=GetImageChannelStatistics(image,exception);
-  status=MagickTrue;
-  distortion=0.0;
-  area=1.0/((MagickRealType) image->columns*image->rows);
-  image_view=AcquireCacheView(image);
-  reconstruct_view=AcquireCacheView(reconstruct_image);
-  for (y=0; y < (ssize_t) image->rows; y++)
-  {
-    register const IndexPacket
-      *restrict indexes,
-      *restrict reconstruct_indexes;
-
-    register const PixelPacket
-      *restrict p,
-      *restrict q;
-
-    register ssize_t
-      x;
-
-    if (status == MagickFalse)
-      continue;
-    p=GetCacheViewVirtualPixels(image_view,0,y,image->columns,1,exception);
-    q=GetCacheViewVirtualPixels(reconstruct_view,0,y,reconstruct_image->columns,
-      1,exception);
-    if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
-      {
-        status=MagickFalse;
-        continue;
-      }
-    indexes=GetCacheViewVirtualIndexQueue(image_view);
-    reconstruct_indexes=GetCacheViewVirtualIndexQueue(reconstruct_view);
-    for (x=0; x < (ssize_t) image->columns; x++)
-    {
-      distortion+=area*QuantumScale*(GetRedPixelComponent(p)-
-        image_statistics[RedChannel].mean)*(GetRedPixelComponent(q)-
-        reconstruct_statistics[RedChannel].mean);
-      distortion+=area*QuantumScale*(GetGreenPixelComponent(p)-
-        image_statistics[GreenChannel].mean)*(GetGreenPixelComponent(q)-
-        reconstruct_statistics[GreenChannel].mean);
-      distortion+=area*QuantumScale*(GetBluePixelComponent(p)-
-        image_statistics[BlueChannel].mean)*(q->blue-
-        reconstruct_statistics[BlueChannel].mean);
-      if (image->matte != MagickFalse)
-        distortion+=area*QuantumScale*(GetOpacityPixelComponent(p)-
-          image_statistics[OpacityChannel].mean)*(GetOpacityPixelComponent(q)-
-          reconstruct_statistics[OpacityChannel].mean);
-      if ((image->colorspace == CMYKColorspace) &&
-          (reconstruct_image->colorspace == CMYKColorspace))
-        distortion+=area*QuantumScale*(GetIndexPixelComponent(indexes+x)-
-          image_statistics[OpacityChannel].mean)*(GetIndexPixelComponent(
-          reconstruct_indexes+x)-reconstruct_statistics[OpacityChannel].mean);
-      p++;
-      q++;
-    }
-  }
-  reconstruct_view=DestroyCacheView(reconstruct_view);
-  image_view=DestroyCacheView(image_view);
-  /*
-    Divide by the standard deviation.
-  */
-  gamma=image_statistics[CompositeChannels].standard_deviation*
-    reconstruct_statistics[CompositeChannels].standard_deviation;
-  gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
-  distortion=QuantumRange*gamma*distortion;
-  number_channels=3;
-  if (image->matte != MagickFalse)
-    number_channels++;
-  if (image->colorspace == CMYKColorspace)
-    number_channels++;
-  distortion=sqrt(distortion/number_channels);
-  /*
-    Free resources.
-  */
-  image_statistics=(ChannelStatistics *) RelinquishMagickMemory(
-    image_statistics);
-  return(1.0-distortion);
-}
-
 static double GetSimilarityMetric(const Image *image,const Image *reference,
-  const ChannelStatistics *reference_statistics,const ssize_t x_offset,
-  const ssize_t y_offset,ExceptionInfo *exception)
+  const MetricType metric,const ssize_t x_offset,const ssize_t y_offset,
+  ExceptionInfo *exception)
 {
   double
     distortion;
@@ -1832,6 +1722,9 @@ static double GetSimilarityMetric(const Image *image,const Image *reference,
   Image
     *similarity_image;
 
+  MagickBooleanType
+    status;
+
   RectangleInfo
     geometry;
 
@@ -1841,23 +1734,34 @@ static double GetSimilarityMetric(const Image *image,const Image *reference,
   similarity_image=CropImage(image,&geometry,exception);
   if (similarity_image == (Image *) NULL)
     return(0.0);
-  distortion=GetNCCDistortion(reference,similarity_image,reference_statistics,
+  distortion=0.0;
+  status=GetImageDistortion(similarity_image,reference,metric,&distortion,
     exception);
+  (void) status;
   similarity_image=DestroyImage(similarity_image);
   return(distortion);
 }
 
 MagickExport Image *SimilarityImage(Image *image,const Image *reference,
   RectangleInfo *offset,double *similarity_metric,ExceptionInfo *exception)
+{
+  Image
+    *similarity_image;
+
+  similarity_image=SimilarityMetricImage(image,reference,
+    RootMeanSquaredErrorMetric,offset,similarity_metric,exception);
+  return(similarity_image);
+}
+
+MagickExport Image *SimilarityMetricImage(Image *image,const Image *reference,
+  const MetricType metric,RectangleInfo *offset,double *similarity_metric,
+  ExceptionInfo *exception)
 {
 #define SimilarityImageTag  "Similarity/Image"
 
   CacheView
     *similarity_view;
 
-  ChannelStatistics
-    *reference_statistics;
-
   Image
     *similarity_image;
 
@@ -1896,10 +1800,9 @@ MagickExport Image *SimilarityImage(Image *image,const Image *reference,
   */
   status=MagickTrue;
   progress=0;
-  reference_statistics=GetImageChannelStatistics(reference,exception);
   similarity_view=AcquireCacheView(similarity_image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(dynamic,4) shared(progress,status)
+  #pragma omp parallel for schedule(static,4) shared(progress,status)
 #endif
   for (y=0; y < (ssize_t) (image->rows-reference->rows+1); y++)
   {
@@ -1923,8 +1826,7 @@ MagickExport Image *SimilarityImage(Image *image,const Image *reference,
       }
     for (x=0; x < (ssize_t) (image->columns-reference->columns+1); x++)
     {
-      similarity=GetSimilarityMetric(image,reference,reference_statistics,x,y,
-        exception);
+      similarity=GetSimilarityMetric(image,reference,metric,x,y,exception);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
   #pragma omp critical (MagickCore_SimilarityImage)
 #endif
@@ -1934,10 +1836,10 @@ MagickExport Image *SimilarityImage(Image *image,const Image *reference,
           offset->x=x;
           offset->y=y;
         }
-      SetRedPixelComponent(q,ClampToQuantum(QuantumRange-QuantumRange*
+      SetPixelRed(q,ClampToQuantum(QuantumRange-QuantumRange*
         similarity));
-      SetGreenPixelComponent(q,GetRedPixelComponent(q));
-      SetBluePixelComponent(q,GetRedPixelComponent(q));
+      SetPixelGreen(q,GetPixelRed(q));
+      SetPixelBlue(q,GetPixelRed(q));
       q++;
     }
     if (SyncCacheViewAuthenticPixels(similarity_view,exception) == MagickFalse)
@@ -1957,7 +1859,5 @@ MagickExport Image *SimilarityImage(Image *image,const Image *reference,
       }
   }
   similarity_view=DestroyCacheView(similarity_view);
-  reference_statistics=(ChannelStatistics *) RelinquishMagickMemory(
-    reference_statistics);
   return(similarity_image);
 }
