@@ -18,7 +18,7 @@
 %                                December 1996                                %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -47,6 +47,7 @@
 #include <windows.h>
 #include "magick/cache.h"
 #include "magick/colorspace.h"
+#include "magick/colorspace-private.h"
 #include "magick/draw.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
@@ -97,8 +98,14 @@ MagickExport void *CropImageToHBITMAP(Image *image,
 {
 #define CropImageTag  "Crop/Image"
 
-  ssize_t
-    y;
+  BITMAP
+    bitmap;
+
+  HBITMAP
+    bitmapH;
+
+  HANDLE
+    bitmap_bitsH;
 
   MagickBooleanType
     proceed;
@@ -109,21 +116,15 @@ MagickExport void *CropImageToHBITMAP(Image *image,
   register const PixelPacket
     *p;
 
-  BITMAP
-    bitmap;
-
-  HBITMAP
-    bitmapH;
-
-  HANDLE
-    bitmap_bitsH;
-
   register RGBQUAD
     *q;
 
   RGBQUAD
     *bitmap_bits;
 
+  ssize_t
+    y;
+
   /*
     Check crop geometry.
   */
@@ -175,7 +176,7 @@ MagickExport void *CropImageToHBITMAP(Image *image,
   bitmap_bits=(RGBQUAD *) GlobalLock((HGLOBAL) bitmap_bitsH);
   if ( bitmap.bmBits == NULL )
     bitmap.bmBits = bitmap_bits;
-  if (image->colorspace != RGBColorspace)
+  if (IsRGBColorspace(image->colorspace) == MagickFalse)
     TransformImageColorspace(image,RGBColorspace);
   /*
     Extract crop image.
@@ -200,9 +201,9 @@ MagickExport void *CropImageToHBITMAP(Image *image,
         /* Transfer pixels, scaling to Quantum */
         for( x=(ssize_t) page.width ; x> 0 ; x-- )
           {
-            q->rgbRed = ScaleQuantumToChar(GetRedPixelComponent(p));
-            q->rgbGreen = ScaleQuantumToChar(GetGreenPixelComponent(p));
-            q->rgbBlue = ScaleQuantumToChar(GetBluePixelComponent(p));
+            q->rgbRed = ScaleQuantumToChar(GetPixelRed(p));
+            q->rgbGreen = ScaleQuantumToChar(GetPixelGreen(p));
+            q->rgbBlue = ScaleQuantumToChar(GetPixelBlue(p));
             q->rgbReserved = 0;
             ++q;
             ++p;
@@ -592,9 +593,6 @@ MagickExport void *ImageToHBITMAP(Image *image)
   HBITMAP
     bitmapH;
 
-  ssize_t
-    y;
-
   register ssize_t
     x;
 
@@ -610,6 +608,9 @@ MagickExport void *ImageToHBITMAP(Image *image)
   size_t
     length;
 
+  ssize_t
+    y;
+
   (void) ResetMagickMemory(&bitmap,0,sizeof(bitmap));
   bitmap.bmType=0;
   bitmap.bmWidth=(LONG) image->columns;
@@ -644,9 +645,9 @@ MagickExport void *ImageToHBITMAP(Image *image)
       break;
     for (x=0; x < (ssize_t) image->columns; x++)
     {
-      q->rgbRed=ScaleQuantumToChar(GetRedPixelComponent(p));
-      q->rgbGreen=ScaleQuantumToChar(GetGreenPixelComponent(p));
-      q->rgbBlue=ScaleQuantumToChar(GetBluePixelComponent(p));
+      q->rgbRed=ScaleQuantumToChar(GetPixelRed(p));
+      q->rgbGreen=ScaleQuantumToChar(GetPixelGreen(p));
+      q->rgbBlue=ScaleQuantumToChar(GetPixelBlue(p));
       q->rgbReserved=0;
       p++;
       q++;
