@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -180,7 +180,7 @@ static MagickPixelPacket **AcquirePixelThreadSet(const Image *image,
   return(pixels);
 }
 
-static inline double MagickMax(const double x,const double y)
+static inline double EvaluateMax(const double x,const double y)
 {
   if (x > y)
     return(x);
@@ -304,7 +304,7 @@ static MagickRealType ApplyEvaluateOperator(RandomInfo *random_info,
     }
     case MaxEvaluateOperator:
     {
-      result=(MagickRealType) MagickMax((double) pixel,value);
+      result=(MagickRealType) EvaluateMax((double) pixel,value);
       break;
     }
     case MeanEvaluateOperator:
@@ -495,7 +495,7 @@ MagickExport Image *EvaluateImages(const Image *images,
   if (op == MedianEvaluateOperator)
     {
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-      #pragma omp parallel for schedule(dynamic) shared(progress,status)
+      #pragma omp parallel for schedule(static) shared(progress,status)
 #endif
       for (y=0; y < (ssize_t) evaluate_image->rows; y++)
       {
@@ -604,7 +604,7 @@ MagickExport Image *EvaluateImages(const Image *images,
   else
     {
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-      #pragma omp parallel for schedule(dynamic) shared(progress,status)
+      #pragma omp parallel for schedule(static) shared(progress,status)
 #endif
       for (y=0; y < (ssize_t) evaluate_image->rows; y++)
       {
@@ -781,7 +781,7 @@ MagickExport MagickBooleanType EvaluateImageChannel(Image *image,
   random_info=AcquireRandomInfoThreadSet();
   image_view=AcquireCacheView(image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(dynamic,4) shared(progress,status)
+  #pragma omp parallel for schedule(static,4) shared(progress,status)
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
   {
@@ -1019,7 +1019,7 @@ MagickExport MagickBooleanType FunctionImageChannel(Image *image,
   progress=0;
   image_view=AcquireCacheView(image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(dynamic,4) shared(progress,status)
+  #pragma omp parallel for schedule(static,4) shared(progress,status)
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
   {
@@ -1802,13 +1802,13 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
   }
   for (i=0; i < (ssize_t) CompositeChannels; i++)
   {
-    channel_statistics[CompositeChannels].depth=(size_t) MagickMax((double)
+    channel_statistics[CompositeChannels].depth=(size_t) EvaluateMax((double)
       channel_statistics[CompositeChannels].depth,(double)
       channel_statistics[i].depth);
     channel_statistics[CompositeChannels].minima=MagickMin(
       channel_statistics[CompositeChannels].minima,
       channel_statistics[i].minima);
-    channel_statistics[CompositeChannels].maxima=MagickMax(
+    channel_statistics[CompositeChannels].maxima=EvaluateMax(
       channel_statistics[CompositeChannels].maxima,
       channel_statistics[i].maxima);
     channel_statistics[CompositeChannels].sum+=channel_statistics[i].sum;
@@ -1863,3 +1863,843 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
   }
   return(channel_statistics);
 }
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%     S t a t i s t i c I m a g e                                             %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  StatisticImage() makes each pixel the min / max / median / mode / etc. of
+%  the neighborhood of the specified width and height.
+%
+%  The format of the StatisticImage method is:
+%
+%      Image *StatisticImage(const Image *image,const StatisticType type,
+%        const size_t width,const size_t height,ExceptionInfo *exception)
+%      Image *StatisticImageChannel(const Image *image,
+%        const ChannelType channel,const StatisticType type,
+%        const size_t width,const size_t height,ExceptionInfo *exception)
+%
+%  A description of each parameter follows:
+%
+%    o image: the image.
+%
+%    o channel: the image channel.
+%
+%    o type: the statistic type (median, mode, etc.).
+%
+%    o width: the width of the pixel neighborhood.
+%
+%    o height: the height of the pixel neighborhood.
+%
+%    o exception: return any errors or warnings in this structure.
+%
+*/
+
+#define ListChannels  5
+
+typedef struct _ListNode
+{
+  size_t
+    next[9],
+    count,
+    signature;
+} ListNode;
+
+typedef struct _SkipList
+{
+  ssize_t
+    level;
+
+  ListNode
+    *nodes;
+} SkipList;
+
+typedef struct _PixelList
+{
+  size_t
+    length,
+    seed,
+    signature;
+
+  SkipList
+    lists[ListChannels];
+} PixelList;
+
+static PixelList *DestroyPixelList(PixelList *pixel_list)
+{
+  register ssize_t
+    i;
+
+  if (pixel_list == (PixelList *) NULL)
+    return((PixelList *) NULL);
+  for (i=0; i < ListChannels; i++)
+    if (pixel_list->lists[i].nodes != (ListNode *) NULL)
+      pixel_list->lists[i].nodes=(ListNode *) RelinquishMagickMemory(
+        pixel_list->lists[i].nodes);
+  pixel_list=(PixelList *) RelinquishMagickMemory(pixel_list);
+  return(pixel_list);
+}
+
+static PixelList **DestroyPixelListThreadSet(PixelList **pixel_list)
+{
+  register ssize_t
+    i;
+
+  assert(pixel_list != (PixelList **) NULL);
+  for (i=0; i < (ssize_t) GetOpenMPMaximumThreads(); i++)
+    if (pixel_list[i] != (PixelList *) NULL)
+      pixel_list[i]=DestroyPixelList(pixel_list[i]);
+  pixel_list=(PixelList **) RelinquishMagickMemory(pixel_list);
+  return(pixel_list);
+}
+
+static PixelList *AcquirePixelList(const size_t width,const size_t height)
+{
+  PixelList
+    *pixel_list;
+
+  register ssize_t
+    i;
+
+  pixel_list=(PixelList *) AcquireMagickMemory(sizeof(*pixel_list));
+  if (pixel_list == (PixelList *) NULL)
+    return(pixel_list);
+  (void) ResetMagickMemory((void *) pixel_list,0,sizeof(*pixel_list));
+  pixel_list->length=width*height;
+  for (i=0; i < ListChannels; i++)
+  {
+    pixel_list->lists[i].nodes=(ListNode *) AcquireQuantumMemory(65537UL,
+      sizeof(*pixel_list->lists[i].nodes));
+    if (pixel_list->lists[i].nodes == (ListNode *) NULL)
+      return(DestroyPixelList(pixel_list));
+    (void) ResetMagickMemory(pixel_list->lists[i].nodes,0,65537UL*
+      sizeof(*pixel_list->lists[i].nodes));
+  }
+  pixel_list->signature=MagickSignature;
+  return(pixel_list);
+}
+
+static PixelList **AcquirePixelListThreadSet(const size_t width,
+  const size_t height)
+{
+  PixelList
+    **pixel_list;
+
+  register ssize_t
+    i;
+
+  size_t
+    number_threads;
+
+  number_threads=GetOpenMPMaximumThreads();
+  pixel_list=(PixelList **) AcquireQuantumMemory(number_threads,
+    sizeof(*pixel_list));
+  if (pixel_list == (PixelList **) NULL)
+    return((PixelList **) NULL);
+  (void) ResetMagickMemory(pixel_list,0,number_threads*sizeof(*pixel_list));
+  for (i=0; i < (ssize_t) number_threads; i++)
+  {
+    pixel_list[i]=AcquirePixelList(width,height);
+    if (pixel_list[i] == (PixelList *) NULL)
+      return(DestroyPixelListThreadSet(pixel_list));
+  }
+  return(pixel_list);
+}
+
+static void AddNodePixelList(PixelList *pixel_list,const ssize_t channel,
+  const size_t color)
+{
+  register SkipList
+    *list;
+
+  register ssize_t
+    level;
+
+  size_t
+    search,
+    update[9];
+
+  /*
+    Initialize the node.
+  */
+  list=pixel_list->lists+channel;
+  list->nodes[color].signature=pixel_list->signature;
+  list->nodes[color].count=1;
+  /*
+    Determine where it belongs in the list.
+  */
+  search=65536UL;
+  for (level=list->level; level >= 0; level--)
+  {
+    while (list->nodes[search].next[level] < color)
+      search=list->nodes[search].next[level];
+    update[level]=search;
+  }
+  /*
+    Generate a pseudo-random level for this node.
+  */
+  for (level=0; ; level++)
+  {
+    pixel_list->seed=(pixel_list->seed*42893621L)+1L;
+    if ((pixel_list->seed & 0x300) != 0x300)
+      break;
+  }
+  if (level > 8)
+    level=8;
+  if (level > (list->level+2))
+    level=list->level+2;
+  /*
+    If we're raising the list's level, link back to the root node.
+  */
+  while (level > list->level)
+  {
+    list->level++;
+    update[list->level]=65536UL;
+  }
+  /*
+    Link the node into the skip-list.
+  */
+  do
+  {
+    list->nodes[color].next[level]=list->nodes[update[level]].next[level];
+    list->nodes[update[level]].next[level]=color;
+  } while (level-- > 0);
+}
+
+static void GetMaximumPixelList(PixelList *pixel_list,MagickPixelPacket *pixel)
+{
+  register SkipList
+    *list;
+
+  register ssize_t
+    channel;
+
+  size_t
+    color,
+    maximum;
+
+  ssize_t
+    count;
+
+  unsigned short
+    channels[ListChannels];
+
+  /*
+    Find the maximum value for each of the color.
+  */
+  for (channel=0; channel < 5; channel++)
+  {
+    list=pixel_list->lists+channel;
+    color=65536L;
+    count=0;
+    maximum=list->nodes[color].next[0];
+    do
+    {
+      color=list->nodes[color].next[0];
+      if (color > maximum)
+        maximum=color;
+      count+=list->nodes[color].count;
+    } while (count < (ssize_t) pixel_list->length);
+    channels[channel]=(unsigned short) maximum;
+  }
+  pixel->red=(MagickRealType) ScaleShortToQuantum(channels[0]);
+  pixel->green=(MagickRealType) ScaleShortToQuantum(channels[1]);
+  pixel->blue=(MagickRealType) ScaleShortToQuantum(channels[2]);
+  pixel->opacity=(MagickRealType) ScaleShortToQuantum(channels[3]);
+  pixel->index=(MagickRealType) ScaleShortToQuantum(channels[4]);
+}
+
+static void GetMeanPixelList(PixelList *pixel_list,MagickPixelPacket *pixel)
+{
+  MagickRealType
+    sum;
+
+  register SkipList
+    *list;
+
+  register ssize_t
+    channel;
+
+  size_t
+    color;
+
+  ssize_t
+    count;
+
+  unsigned short
+    channels[ListChannels];
+
+  /*
+    Find the mean value for each of the color.
+  */
+  for (channel=0; channel < 5; channel++)
+  {
+    list=pixel_list->lists+channel;
+    color=65536L;
+    count=0;
+    sum=0.0;
+    do
+    {
+      color=list->nodes[color].next[0];
+      sum+=(MagickRealType) list->nodes[color].count*color;
+      count+=list->nodes[color].count;
+    } while (count < (ssize_t) pixel_list->length);
+    sum/=pixel_list->length;
+    channels[channel]=(unsigned short) sum;
+  }
+  pixel->red=(MagickRealType) ScaleShortToQuantum(channels[0]);
+  pixel->green=(MagickRealType) ScaleShortToQuantum(channels[1]);
+  pixel->blue=(MagickRealType) ScaleShortToQuantum(channels[2]);
+  pixel->opacity=(MagickRealType) ScaleShortToQuantum(channels[3]);
+  pixel->index=(MagickRealType) ScaleShortToQuantum(channels[4]);
+}
+
+static void GetMedianPixelList(PixelList *pixel_list,MagickPixelPacket *pixel)
+{
+  register SkipList
+    *list;
+
+  register ssize_t
+    channel;
+
+  size_t
+    color;
+
+  ssize_t
+    count;
+
+  unsigned short
+    channels[ListChannels];
+
+  /*
+    Find the median value for each of the color.
+  */
+  for (channel=0; channel < 5; channel++)
+  {
+    list=pixel_list->lists+channel;
+    color=65536L;
+    count=0;
+    do
+    {
+      color=list->nodes[color].next[0];
+      count+=list->nodes[color].count;
+    } while (count <= (ssize_t) (pixel_list->length >> 1));
+    channels[channel]=(unsigned short) color;
+  }
+  GetMagickPixelPacket((const Image *) NULL,pixel);
+  pixel->red=(MagickRealType) ScaleShortToQuantum(channels[0]);
+  pixel->green=(MagickRealType) ScaleShortToQuantum(channels[1]);
+  pixel->blue=(MagickRealType) ScaleShortToQuantum(channels[2]);
+  pixel->opacity=(MagickRealType) ScaleShortToQuantum(channels[3]);
+  pixel->index=(MagickRealType) ScaleShortToQuantum(channels[4]);
+}
+
+static void GetMinimumPixelList(PixelList *pixel_list,MagickPixelPacket *pixel)
+{
+  register SkipList
+    *list;
+
+  register ssize_t
+    channel;
+
+  size_t
+    color,
+    minimum;
+
+  ssize_t
+    count;
+
+  unsigned short
+    channels[ListChannels];
+
+  /*
+    Find the minimum value for each of the color.
+  */
+  for (channel=0; channel < 5; channel++)
+  {
+    list=pixel_list->lists+channel;
+    count=0;
+    color=65536UL;
+    minimum=list->nodes[color].next[0];
+    do
+    {
+      color=list->nodes[color].next[0];
+      if (color < minimum)
+        minimum=color;
+      count+=list->nodes[color].count;
+    } while (count < (ssize_t) pixel_list->length);
+    channels[channel]=(unsigned short) minimum;
+  }
+  pixel->red=(MagickRealType) ScaleShortToQuantum(channels[0]);
+  pixel->green=(MagickRealType) ScaleShortToQuantum(channels[1]);
+  pixel->blue=(MagickRealType) ScaleShortToQuantum(channels[2]);
+  pixel->opacity=(MagickRealType) ScaleShortToQuantum(channels[3]);
+  pixel->index=(MagickRealType) ScaleShortToQuantum(channels[4]);
+}
+
+static void GetModePixelList(PixelList *pixel_list,MagickPixelPacket *pixel)
+{
+  register SkipList
+    *list;
+
+  register ssize_t
+    channel;
+
+  size_t
+    color,
+    max_count,
+    mode;
+
+  ssize_t
+    count;
+
+  unsigned short
+    channels[5];
+
+  /*
+    Make each pixel the 'predominant color' of the specified neighborhood.
+  */
+  for (channel=0; channel < 5; channel++)
+  {
+    list=pixel_list->lists+channel;
+    color=65536L;
+    mode=color;
+    max_count=list->nodes[mode].count;
+    count=0;
+    do
+    {
+      color=list->nodes[color].next[0];
+      if (list->nodes[color].count > max_count)
+        {
+          mode=color;
+          max_count=list->nodes[mode].count;
+        }
+      count+=list->nodes[color].count;
+    } while (count < (ssize_t) pixel_list->length);
+    channels[channel]=(unsigned short) mode;
+  }
+  pixel->red=(MagickRealType) ScaleShortToQuantum(channels[0]);
+  pixel->green=(MagickRealType) ScaleShortToQuantum(channels[1]);
+  pixel->blue=(MagickRealType) ScaleShortToQuantum(channels[2]);
+  pixel->opacity=(MagickRealType) ScaleShortToQuantum(channels[3]);
+  pixel->index=(MagickRealType) ScaleShortToQuantum(channels[4]);
+}
+
+static void GetNonpeakPixelList(PixelList *pixel_list,MagickPixelPacket *pixel)
+{
+  register SkipList
+    *list;
+
+  register ssize_t
+    channel;
+
+  size_t
+    color,
+    next,
+    previous;
+
+  ssize_t
+    count;
+
+  unsigned short
+    channels[5];
+
+  /*
+    Finds the non peak value for each of the colors.
+  */
+  for (channel=0; channel < 5; channel++)
+  {
+    list=pixel_list->lists+channel;
+    color=65536L;
+    next=list->nodes[color].next[0];
+    count=0;
+    do
+    {
+      previous=color;
+      color=next;
+      next=list->nodes[color].next[0];
+      count+=list->nodes[color].count;
+    } while (count <= (ssize_t) (pixel_list->length >> 1));
+    if ((previous == 65536UL) && (next != 65536UL))
+      color=next;
+    else
+      if ((previous != 65536UL) && (next == 65536UL))
+        color=previous;
+    channels[channel]=(unsigned short) color;
+  }
+  pixel->red=(MagickRealType) ScaleShortToQuantum(channels[0]);
+  pixel->green=(MagickRealType) ScaleShortToQuantum(channels[1]);
+  pixel->blue=(MagickRealType) ScaleShortToQuantum(channels[2]);
+  pixel->opacity=(MagickRealType) ScaleShortToQuantum(channels[3]);
+  pixel->index=(MagickRealType) ScaleShortToQuantum(channels[4]);
+}
+
+static void GetStandardDeviationPixelList(PixelList *pixel_list,
+  MagickPixelPacket *pixel)
+{
+  MagickRealType
+    sum,
+    sum_squared;
+
+  register SkipList
+    *list;
+
+  register ssize_t
+    channel;
+
+  size_t
+    color;
+
+  ssize_t
+    count;
+
+  unsigned short
+    channels[ListChannels];
+
+  /*
+    Find the standard-deviation value for each of the color.
+  */
+  for (channel=0; channel < 5; channel++)
+  {
+    list=pixel_list->lists+channel;
+    color=65536L;
+    count=0;
+    sum=0.0;
+    sum_squared=0.0;
+    do
+    {
+      register ssize_t
+        i;
+
+      color=list->nodes[color].next[0];
+      sum+=(MagickRealType) list->nodes[color].count*color;
+      for (i=0; i < (ssize_t) list->nodes[color].count; i++)
+        sum_squared+=((MagickRealType) color)*((MagickRealType) color);
+      count+=list->nodes[color].count;
+    } while (count < (ssize_t) pixel_list->length);
+    sum/=pixel_list->length;
+    sum_squared/=pixel_list->length;
+    channels[channel]=(unsigned short) sqrt(sum_squared-(sum*sum));
+  }
+  pixel->red=(MagickRealType) ScaleShortToQuantum(channels[0]);
+  pixel->green=(MagickRealType) ScaleShortToQuantum(channels[1]);
+  pixel->blue=(MagickRealType) ScaleShortToQuantum(channels[2]);
+  pixel->opacity=(MagickRealType) ScaleShortToQuantum(channels[3]);
+  pixel->index=(MagickRealType) ScaleShortToQuantum(channels[4]);
+}
+
+static inline void InsertPixelList(const Image *image,const PixelPacket *pixel,
+  const IndexPacket *indexes,PixelList *pixel_list)
+{
+  size_t
+    signature;
+
+  unsigned short
+    index;
+
+  index=ScaleQuantumToShort(GetPixelRed(pixel));
+  signature=pixel_list->lists[0].nodes[index].signature;
+  if (signature == pixel_list->signature)
+    pixel_list->lists[0].nodes[index].count++;
+  else
+    AddNodePixelList(pixel_list,0,index);
+  index=ScaleQuantumToShort(GetPixelGreen(pixel));
+  signature=pixel_list->lists[1].nodes[index].signature;
+  if (signature == pixel_list->signature)
+    pixel_list->lists[1].nodes[index].count++;
+  else
+    AddNodePixelList(pixel_list,1,index);
+  index=ScaleQuantumToShort(GetPixelBlue(pixel));
+  signature=pixel_list->lists[2].nodes[index].signature;
+  if (signature == pixel_list->signature)
+    pixel_list->lists[2].nodes[index].count++;
+  else
+    AddNodePixelList(pixel_list,2,index);
+  index=ScaleQuantumToShort(GetPixelOpacity(pixel));
+  signature=pixel_list->lists[3].nodes[index].signature;
+  if (signature == pixel_list->signature)
+    pixel_list->lists[3].nodes[index].count++;
+  else
+    AddNodePixelList(pixel_list,3,index);
+  if (image->colorspace == CMYKColorspace)
+    index=ScaleQuantumToShort(GetPixelIndex(indexes));
+  signature=pixel_list->lists[4].nodes[index].signature;
+  if (signature == pixel_list->signature)
+    pixel_list->lists[4].nodes[index].count++;
+  else
+    AddNodePixelList(pixel_list,4,index);
+}
+
+static inline MagickRealType MagickAbsoluteValue(const MagickRealType x)
+{
+  if (x < 0)
+    return(-x);
+  return(x);
+}
+
+static void ResetPixelList(PixelList *pixel_list)
+{
+  int
+    level;
+
+  register ListNode
+    *root;
+
+  register SkipList
+    *list;
+
+  register ssize_t
+    channel;
+
+  /*
+    Reset the skip-list.
+  */
+  for (channel=0; channel < 5; channel++)
+  {
+    list=pixel_list->lists+channel;
+    root=list->nodes+65536UL;
+    list->level=0;
+    for (level=0; level < 9; level++)
+      root->next[level]=65536UL;
+  }
+  pixel_list->seed=pixel_list->signature++;
+}
+
+MagickExport Image *StatisticImage(const Image *image,const StatisticType type,
+  const size_t width,const size_t height,ExceptionInfo *exception)
+{
+  Image
+    *statistic_image;
+
+  statistic_image=StatisticImageChannel(image,DefaultChannels,type,width,
+    height,exception);
+  return(statistic_image);
+}
+
+MagickExport Image *StatisticImageChannel(const Image *image,
+  const ChannelType channel,const StatisticType type,const size_t width,
+  const size_t height,ExceptionInfo *exception)
+{
+#define StatisticImageTag  "Statistic/Image"
+
+  CacheView
+    *image_view,
+    *statistic_view;
+
+  Image
+    *statistic_image;
+
+  MagickBooleanType
+    status;
+
+  MagickOffsetType
+    progress;
+
+  PixelList
+    **restrict pixel_list;
+
+  ssize_t
+    neighbor_height,
+    neighbor_width;
+
+  ssize_t
+    y;
+
+  /*
+    Initialize statistics image attributes.
+  */
+  assert(image != (Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
+  assert(exception != (ExceptionInfo *) NULL);
+  assert(exception->signature == MagickSignature);
+  statistic_image=CloneImage(image,image->columns,image->rows,MagickTrue,
+    exception);
+  if (statistic_image == (Image *) NULL)
+    return((Image *) NULL);
+  if (SetImageStorageClass(statistic_image,DirectClass) == MagickFalse)
+    {
+      InheritException(exception,&statistic_image->exception);
+      statistic_image=DestroyImage(statistic_image);
+      return((Image *) NULL);
+    }
+  neighbor_width=width == 0 ? GetOptimalKernelWidth2D((double) width,0.5) : width;
+  neighbor_height=height == 0 ? GetOptimalKernelWidth2D((double) height,0.5) :
+    height;
+  pixel_list=AcquirePixelListThreadSet(neighbor_width,neighbor_height);
+  if (pixel_list == (PixelList **) NULL)
+    {
+      statistic_image=DestroyImage(statistic_image);
+      ThrowImageException(ResourceLimitError,"MemoryAllocationFailed");
+    }
+  /*
+    Make each pixel the min / max / median / mode / etc. of the neighborhood.
+  */
+  status=MagickTrue;
+  progress=0;
+  image_view=AcquireCacheView(image);
+  statistic_view=AcquireCacheView(statistic_image);
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(static,4) shared(progress,status)
+#endif
+  for (y=0; y < (ssize_t) statistic_image->rows; y++)
+  {
+    const int
+      id = GetOpenMPThreadId();
+
+    register const IndexPacket
+      *restrict indexes;
+
+    register const PixelPacket
+      *restrict p;
+
+    register IndexPacket
+      *restrict statistic_indexes;
+
+    register PixelPacket
+      *restrict q;
+
+    register ssize_t
+      x;
+
+    if (status == MagickFalse)
+      continue;
+    p=GetCacheViewVirtualPixels(image_view,-((ssize_t) neighbor_width/2L),y-
+      (ssize_t) (neighbor_height/2L),image->columns+neighbor_width,
+      neighbor_height,exception);
+    q=QueueCacheViewAuthenticPixels(statistic_view,0,y,statistic_image->columns,      1,exception);
+    if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
+      {
+        status=MagickFalse;
+        continue;
+      }
+    indexes=GetCacheViewVirtualIndexQueue(image_view);
+    statistic_indexes=GetCacheViewAuthenticIndexQueue(statistic_view);
+    for (x=0; x < (ssize_t) statistic_image->columns; x++)
+    {
+      MagickPixelPacket
+        pixel;
+
+      register const IndexPacket
+        *restrict s;
+
+      register const PixelPacket
+        *restrict r;
+
+      register ssize_t
+        u,
+        v;
+
+      r=p;
+      s=indexes+x;
+      ResetPixelList(pixel_list[id]);
+      for (v=0; v < (ssize_t) neighbor_height; v++)
+      {
+        for (u=0; u < (ssize_t) neighbor_width; u++)
+          InsertPixelList(image,r+u,s+u,pixel_list[id]);
+        r+=image->columns+neighbor_width;
+        s+=image->columns+neighbor_width;
+      }
+      GetMagickPixelPacket(image,&pixel);
+      SetMagickPixelPacket(image,p+neighbor_width*neighbor_height/2,indexes+
+        neighbor_width*neighbor_height/2+x,&pixel);
+      switch (type)
+      {
+        case GradientStatistic:
+        {
+          MagickPixelPacket
+            maximum,
+            minimum;
+
+          GetMinimumPixelList(pixel_list[id],&pixel);
+          minimum=pixel;
+          GetMaximumPixelList(pixel_list[id],&pixel);
+          maximum=pixel;
+          pixel.red=MagickAbsoluteValue(maximum.red-minimum.red);
+          pixel.green=MagickAbsoluteValue(maximum.green-minimum.green);
+          pixel.blue=MagickAbsoluteValue(maximum.blue-minimum.blue);
+          pixel.opacity=MagickAbsoluteValue(maximum.opacity-minimum.opacity);
+          if (image->colorspace == CMYKColorspace)
+            pixel.index=MagickAbsoluteValue(maximum.index-minimum.index);
+          break;
+        }
+        case MaximumStatistic:
+        {
+          GetMaximumPixelList(pixel_list[id],&pixel);
+          break;
+        }
+        case MeanStatistic:
+        {
+          GetMeanPixelList(pixel_list[id],&pixel);
+          break;
+        }
+        case MedianStatistic:
+        default:
+        {
+          GetMedianPixelList(pixel_list[id],&pixel);
+          break;
+        }
+        case MinimumStatistic:
+        {
+          GetMinimumPixelList(pixel_list[id],&pixel);
+          break;
+        }
+        case ModeStatistic:
+        {
+          GetModePixelList(pixel_list[id],&pixel);
+          break;
+        }
+        case NonpeakStatistic:
+        {
+          GetNonpeakPixelList(pixel_list[id],&pixel);
+          break;
+        }
+        case StandardDeviationStatistic:
+        {
+          GetStandardDeviationPixelList(pixel_list[id],&pixel);
+          break;
+        }
+      }
+      if ((channel & RedChannel) != 0)
+        SetPixelRed(q,ClampToQuantum(pixel.red));
+      if ((channel & GreenChannel) != 0)
+        SetPixelGreen(q,ClampToQuantum(pixel.green));
+      if ((channel & BlueChannel) != 0)
+        SetPixelBlue(q,ClampToQuantum(pixel.blue));
+      if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
+        SetPixelOpacity(q,ClampToQuantum(pixel.opacity));
+      if (((channel & IndexChannel) != 0) &&
+          (image->colorspace == CMYKColorspace))
+        SetPixelIndex(statistic_indexes+x,ClampToQuantum(pixel.index));
+      p++;
+      q++;
+    }
+    if (SyncCacheViewAuthenticPixels(statistic_view,exception) == MagickFalse)
+      status=MagickFalse;
+    if (image->progress_monitor != (MagickProgressMonitor) NULL)
+      {
+        MagickBooleanType
+          proceed;
+
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp critical (MagickCore_StatisticImage)
+#endif
+        proceed=SetImageProgress(image,StatisticImageTag,progress++,
+          image->rows);
+        if (proceed == MagickFalse)
+          status=MagickFalse;
+      }
+  }
+  statistic_view=DestroyCacheView(statistic_view);
+  image_view=DestroyCacheView(image_view);
+  pixel_list=DestroyPixelListThreadSet(pixel_list);
+  return(statistic_image);
+}
