@@ -17,7 +17,7 @@
 %                                 October 1996                                %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -195,7 +195,7 @@ MagickExport Image *AdaptiveThresholdImage(const Image *image,
   image_view=AcquireCacheView(image);
   threshold_view=AcquireCacheView(threshold_image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(dynamic,4) shared(progress,status)
+  #pragma omp parallel for schedule(static,4) shared(progress,status)
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
   {
@@ -257,8 +257,7 @@ MagickExport Image *AdaptiveThresholdImage(const Image *image,
           pixel.blue+=r[u].blue;
           pixel.opacity+=r[u].opacity;
           if (image->colorspace == CMYKColorspace)
-            pixel.index=(MagickRealType) GetIndexPixelComponent(
-              indexes+x+(r-p)+u);
+            pixel.index=(MagickRealType) GetPixelIndex(indexes+x+(r-p)+u);
         }
         r+=image->columns+width;
       }
@@ -268,18 +267,18 @@ MagickExport Image *AdaptiveThresholdImage(const Image *image,
       mean.opacity=(MagickRealType) (pixel.opacity/number_pixels+offset);
       if (image->colorspace == CMYKColorspace)
         mean.index=(MagickRealType) (pixel.index/number_pixels+offset);
-      SetRedPixelComponent(q,((MagickRealType) GetRedPixelComponent(q) <=
-        mean.red) ? 0 : QuantumRange);
-      SetGreenPixelComponent(q,((MagickRealType) GetGreenPixelComponent(q) <=
-        mean.green) ? 0 : QuantumRange);
-      SetBluePixelComponent(q,((MagickRealType) GetBluePixelComponent(q) <=
-        mean.blue) ? 0 : QuantumRange);
-      SetOpacityPixelComponent(q,((MagickRealType) GetOpacityPixelComponent(q)
-        <= mean.opacity) ? 0 : QuantumRange);
+      SetPixelRed(q,((MagickRealType) GetPixelRed(q) <= mean.red) ?
+        0 : QuantumRange);
+      SetPixelGreen(q,((MagickRealType) GetPixelGreen(q) <= mean.green) ?
+        0 : QuantumRange);
+      SetPixelBlue(q,((MagickRealType) GetPixelBlue(q) <= mean.blue) ?
+        0 : QuantumRange);
+      SetPixelOpacity(q,((MagickRealType) GetPixelOpacity(q) <= mean.opacity) ?
+         0 : QuantumRange);
       if (image->colorspace == CMYKColorspace)
-        SetIndexPixelComponent(threshold_indexes+x,(((MagickRealType)
-          GetIndexPixelComponent(threshold_indexes+x) <= mean.index) ? 0 :
-          QuantumRange));
+        SetPixelIndex(threshold_indexes+x,(((MagickRealType)
+          GetPixelIndex(threshold_indexes+x) <= mean.index) ?
+          0 : QuantumRange));
       p++;
       q++;
     }
@@ -393,7 +392,7 @@ MagickExport MagickBooleanType BilevelImageChannel(Image *image,
   exception=(&image->exception);
   image_view=AcquireCacheView(image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(dynamic,4) shared(progress,status)
+  #pragma omp parallel for schedule(static,8) shared(progress,status)
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
   {
@@ -419,10 +418,10 @@ MagickExport MagickBooleanType BilevelImageChannel(Image *image,
       {
         for (x=0; x < (ssize_t) image->columns; x++)
         {
-          SetRedPixelComponent(q,(MagickRealType) PixelIntensityToQuantum(q) <=
+          SetPixelRed(q,(MagickRealType) PixelIntensityToQuantum(q) <=
             threshold ? 0 : QuantumRange);
-          SetGreenPixelComponent(q,GetRedPixelComponent(q));
-          SetBluePixelComponent(q,GetRedPixelComponent(q));
+          SetPixelGreen(q,GetPixelRed(q));
+          SetPixelBlue(q,GetPixelRed(q));
           q++;
         }
       }
@@ -430,28 +429,28 @@ MagickExport MagickBooleanType BilevelImageChannel(Image *image,
       for (x=0; x < (ssize_t) image->columns; x++)
       {
         if ((channel & RedChannel) != 0)
-          SetRedPixelComponent(q,(MagickRealType) GetRedPixelComponent(q) <=
+          SetPixelRed(q,(MagickRealType) GetPixelRed(q) <=
             threshold ? 0 : QuantumRange);
         if ((channel & GreenChannel) != 0)
-          SetGreenPixelComponent(q,(MagickRealType) GetGreenPixelComponent(q) <=
+          SetPixelGreen(q,(MagickRealType) GetPixelGreen(q) <=
             threshold ? 0 : QuantumRange);
         if ((channel & BlueChannel) != 0)
-          SetBluePixelComponent(q,(MagickRealType) GetBluePixelComponent(q) <=
+          SetPixelBlue(q,(MagickRealType) GetPixelBlue(q) <=
             threshold ? 0 : QuantumRange);
         if ((channel & OpacityChannel) != 0)
           {
             if (image->matte == MagickFalse)
-              SetOpacityPixelComponent(q,(MagickRealType)
-                GetOpacityPixelComponent(q) <= threshold ? 0 : QuantumRange);
+              SetPixelOpacity(q,(MagickRealType)
+                GetPixelOpacity(q) <= threshold ? 0 : QuantumRange);
             else
-              SetOpacityPixelComponent(q,(MagickRealType)
-                GetOpacityPixelComponent(q) <= threshold ? OpaqueOpacity :
+              SetPixelOpacity(q,(MagickRealType)
+                GetPixelOpacity(q) <= threshold ? OpaqueOpacity :
                 TransparentOpacity);
           }
         if (((channel & IndexChannel) != 0) &&
             (image->colorspace == CMYKColorspace))
-          SetIndexPixelComponent(indexes+x,(MagickRealType)
-            GetIndexPixelComponent(indexes+x) <= threshold ? 0 : QuantumRange);
+          SetPixelIndex(indexes+x,(MagickRealType)
+            GetPixelIndex(indexes+x) <= threshold ? 0 : QuantumRange);
         q++;
       }
     if (SyncCacheViewAuthenticPixels(image_view,exception) == MagickFalse)
@@ -582,7 +581,7 @@ MagickExport MagickBooleanType BlackThresholdImageChannel(Image *image,
   progress=0;
   image_view=AcquireCacheView(image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(dynamic,4) shared(progress,status)
+  #pragma omp parallel for schedule(static,8) shared(progress,status)
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
   {
@@ -606,36 +605,36 @@ MagickExport MagickBooleanType BlackThresholdImageChannel(Image *image,
     indexes=GetCacheViewAuthenticIndexQueue(image_view);
     for (x=0; x < (ssize_t) image->columns; x++)
     {
-      if (channel != DefaultChannels)
+      if (channel == DefaultChannels)
         {
           if (PixelIntensity(q) < MagickPixelIntensity(&threshold))
             {
-              SetRedPixelComponent(q,0);
-              SetGreenPixelComponent(q,0);
-              SetBluePixelComponent(q,0);
+              SetPixelRed(q,0);
+              SetPixelGreen(q,0);
+              SetPixelBlue(q,0);
               if (image->colorspace == CMYKColorspace)
-                SetIndexPixelComponent(indexes+x,0);
+                SetPixelIndex(indexes+x,0);
             }
         }
       else
         {
           if (((channel & RedChannel) != 0) &&
-              ((MagickRealType) GetRedPixelComponent(q) < threshold.red))
-            SetRedPixelComponent(q,0);
+              ((MagickRealType) GetPixelRed(q) < threshold.red))
+            SetPixelRed(q,0);
           if (((channel & GreenChannel) != 0) &&
-              ((MagickRealType) GetGreenPixelComponent(q) < threshold.green))
-            SetGreenPixelComponent(q,0);
+              ((MagickRealType) GetPixelGreen(q) < threshold.green))
+            SetPixelGreen(q,0);
           if (((channel & BlueChannel) != 0) &&
-              ((MagickRealType) GetBluePixelComponent(q) < threshold.blue))
-            SetBluePixelComponent(q,0);
+              ((MagickRealType) GetPixelBlue(q) < threshold.blue))
+            SetPixelBlue(q,0);
           if (((channel & OpacityChannel) != 0) &&
-              ((MagickRealType) GetOpacityPixelComponent(q) < threshold.opacity))
-            SetOpacityPixelComponent(q,0);
+              ((MagickRealType) GetPixelOpacity(q) < threshold.opacity))
+            SetPixelOpacity(q,0);
           if (((channel & IndexChannel) != 0) &&
               (image->colorspace == CMYKColorspace) &&
-              ((MagickRealType) GetIndexPixelComponent(indexes+x) <
+              ((MagickRealType) GetPixelIndex(indexes+x) <
               threshold.index))
-            SetIndexPixelComponent(indexes+x,0);
+            SetPixelIndex(indexes+x,0);
         }
       q++;
     }
@@ -743,14 +742,14 @@ MagickExport MagickBooleanType ClampImageChannel(Image *image,
       q=image->colormap;
       for (i=0; i < (ssize_t) image->colors; i++)
       {
-        SetRedPixelComponent(q,ClampToUnsignedQuantum(
-          GetRedPixelComponent(q)));
-        SetGreenPixelComponent(q,ClampToUnsignedQuantum(
-          GetGreenPixelComponent(q)));
-        SetBluePixelComponent(q,ClampToUnsignedQuantum(
-          GetBluePixelComponent(q)));
-        SetOpacityPixelComponent(q,ClampToUnsignedQuantum(
-          GetOpacityPixelComponent(q)));
+        SetPixelRed(q,ClampToUnsignedQuantum(
+          GetPixelRed(q)));
+        SetPixelGreen(q,ClampToUnsignedQuantum(
+          GetPixelGreen(q)));
+        SetPixelBlue(q,ClampToUnsignedQuantum(
+          GetPixelBlue(q)));
+        SetPixelOpacity(q,ClampToUnsignedQuantum(
+          GetPixelOpacity(q)));
         q++;
       }
       return(SyncImage(image));
@@ -763,7 +762,7 @@ MagickExport MagickBooleanType ClampImageChannel(Image *image,
   exception=(&image->exception);
   image_view=AcquireCacheView(image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(dynamic,4) shared(progress,status)
+  #pragma omp parallel for schedule(static,8) shared(progress,status)
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
   {
@@ -788,21 +787,21 @@ MagickExport MagickBooleanType ClampImageChannel(Image *image,
     for (x=0; x < (ssize_t) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
-        SetRedPixelComponent(q,ClampToUnsignedQuantum(
-          GetRedPixelComponent(q)));
+        SetPixelRed(q,ClampToUnsignedQuantum(
+          GetPixelRed(q)));
       if ((channel & GreenChannel) != 0)
-        SetGreenPixelComponent(q,ClampToUnsignedQuantum(
-          GetGreenPixelComponent(q)));
+        SetPixelGreen(q,ClampToUnsignedQuantum(
+          GetPixelGreen(q)));
       if ((channel & BlueChannel) != 0)
-        SetBluePixelComponent(q,ClampToUnsignedQuantum(
-          GetBluePixelComponent(q)));
+        SetPixelBlue(q,ClampToUnsignedQuantum(
+          GetPixelBlue(q)));
       if ((channel & OpacityChannel) != 0)
-        SetOpacityPixelComponent(q,ClampToUnsignedQuantum(
-          GetOpacityPixelComponent(q)));
+        SetPixelOpacity(q,ClampToUnsignedQuantum(
+          GetPixelOpacity(q)));
       if (((channel & IndexChannel) != 0) &&
           (image->colorspace == CMYKColorspace))
-        SetIndexPixelComponent(indexes+x,ClampToUnsignedQuantum(
-          GetIndexPixelComponent(indexes+x)));
+        SetPixelIndex(indexes+x,ClampToUnsignedQuantum(
+          GetPixelIndex(indexes+x)));
       q++;
     }
     if (SyncCacheViewAuthenticPixels(image_view,exception) == MagickFalse)
@@ -1413,7 +1412,7 @@ MagickExport MagickBooleanType OrderedPosterizeImageChannel(Image *image,
     threshold_map=p;
     while (((isspace((int) ((unsigned char) *p)) == 0) && (*p != ',')) &&
                     (*p != '\0')) {
-      if ((p-threshold_map) >= MaxTextExtent)
+      if ((p-threshold_map) >= (MaxTextExtent-1))
         break;
       token[p-threshold_map] = *p;
       p++;
@@ -1503,7 +1502,7 @@ printf("DEBUG levels  r=%u g=%u b=%u a=%u i=%u\n",
     progress=0;
     image_view=AcquireCacheView(image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(dynamic,4) shared(progress,status)
+  #pragma omp parallel for schedule(static,8) shared(progress,status)
 #endif
     for (y=0; y < (ssize_t) image->rows; y++)
     {
@@ -1550,38 +1549,38 @@ printf("DEBUG levels  r=%u g=%u b=%u a=%u i=%u\n",
               Opacity is inverted so 'off' represents transparent.
         */
         if (levels.red) {
-          t = (ssize_t) (QuantumScale*GetRedPixelComponent(q)*(levels.red*d+1));
+          t = (ssize_t) (QuantumScale*GetPixelRed(q)*(levels.red*d+1));
           l = t/d;  t = t-l*d;
-          SetRedPixelComponent(q,RoundToQuantum((MagickRealType)
+          SetPixelRed(q,RoundToQuantum((MagickRealType)
             ((l+(t >= threshold))*(MagickRealType) QuantumRange/levels.red)));
         }
         if (levels.green) {
-          t = (ssize_t) (QuantumScale*GetGreenPixelComponent(q)*
+          t = (ssize_t) (QuantumScale*GetPixelGreen(q)*
             (levels.green*d+1));
           l = t/d;  t = t-l*d;
-          SetGreenPixelComponent(q,RoundToQuantum((MagickRealType)
+          SetPixelGreen(q,RoundToQuantum((MagickRealType)
             ((l+(t >= threshold))*(MagickRealType) QuantumRange/levels.green)));
         }
         if (levels.blue) {
-          t = (ssize_t) (QuantumScale*GetBluePixelComponent(q)*
+          t = (ssize_t) (QuantumScale*GetPixelBlue(q)*
             (levels.blue*d+1));
           l = t/d;  t = t-l*d;
-          SetBluePixelComponent(q,RoundToQuantum((MagickRealType)
+          SetPixelBlue(q,RoundToQuantum((MagickRealType)
             ((l+(t >= threshold))*(MagickRealType) QuantumRange/levels.blue)));
         }
         if (levels.opacity) {
-          t = (ssize_t) ((1.0-QuantumScale*GetOpacityPixelComponent(q))*
+          t = (ssize_t) ((1.0-QuantumScale*GetPixelOpacity(q))*
             (levels.opacity*d+1));
           l = t/d;  t = t-l*d;
-          SetOpacityPixelComponent(q,RoundToQuantum((MagickRealType)
+          SetPixelOpacity(q,RoundToQuantum((MagickRealType)
             ((1.0-l-(t >= threshold))*(MagickRealType) QuantumRange/
             levels.opacity)));
         }
         if (levels.index) {
-          t = (ssize_t) (QuantumScale*GetIndexPixelComponent(indexes+x)*
+          t = (ssize_t) (QuantumScale*GetPixelIndex(indexes+x)*
             (levels.index*d+1));
           l = t/d;  t = t-l*d;
-          SetIndexPixelComponent(indexes+x,RoundToQuantum((MagickRealType) ((l+
+          SetPixelIndex(indexes+x,RoundToQuantum((MagickRealType) ((l+
             (t>=threshold))*(MagickRealType) QuantumRange/levels.index)));
         }
         q++;
@@ -1732,7 +1731,7 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
       random_info=AcquireRandomInfoThreadSet();
       image_view=AcquireCacheView(image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-      #pragma omp parallel for schedule(dynamic,4) shared(progress,status)
+      #pragma omp parallel for schedule(static,8) shared(progress,status)
 #endif
       for (y=0; y < (ssize_t) image->rows; y++)
       {
@@ -1778,10 +1777,8 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
             threshold.index=(MagickRealType)(QuantumRange*
               GetPseudoRandomValue(random_info[id]));
           index=(IndexPacket) (intensity <= threshold.index ? 0 : 1);
-          SetIndexPixelComponent(indexes+x,index);
-          SetRedPixelComponent(q,image->colormap[(ssize_t) index].red);
-          SetGreenPixelComponent(q,image->colormap[(ssize_t) index].green);
-          SetBluePixelComponent(q,image->colormap[(ssize_t) index].blue);
+          SetPixelIndex(indexes+x,index);
+          SetPixelRGBO(q,image->colormap+(ssize_t) index);
           q++;
         }
         sync=SyncCacheViewAuthenticPixels(image_view,exception);
@@ -1813,7 +1810,7 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
   random_info=AcquireRandomInfoThreadSet();
   image_view=AcquireCacheView(image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(dynamic,4) shared(progress,status)
+  #pragma omp parallel for schedule(static,8) shared(progress,status)
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
   {
@@ -1842,10 +1839,10 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
     {
       if ((channel & RedChannel) != 0)
         {
-          if ((MagickRealType) GetRedPixelComponent(q) < min_threshold)
+          if ((MagickRealType) GetPixelRed(q) < min_threshold)
             threshold.red=min_threshold;
           else
-            if ((MagickRealType) GetRedPixelComponent(q) > max_threshold)
+            if ((MagickRealType) GetPixelRed(q) > max_threshold)
               threshold.red=max_threshold;
             else
               threshold.red=(MagickRealType) (QuantumRange*
@@ -1853,10 +1850,10 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
         }
       if ((channel & GreenChannel) != 0)
         {
-          if ((MagickRealType) GetGreenPixelComponent(q) < min_threshold)
+          if ((MagickRealType) GetPixelGreen(q) < min_threshold)
             threshold.green=min_threshold;
           else
-            if ((MagickRealType) GetGreenPixelComponent(q) > max_threshold)
+            if ((MagickRealType) GetPixelGreen(q) > max_threshold)
               threshold.green=max_threshold;
             else
               threshold.green=(MagickRealType) (QuantumRange*
@@ -1864,10 +1861,10 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
         }
       if ((channel & BlueChannel) != 0)
         {
-          if ((MagickRealType) GetBluePixelComponent(q) < min_threshold)
+          if ((MagickRealType) GetPixelBlue(q) < min_threshold)
             threshold.blue=min_threshold;
           else
-            if ((MagickRealType) GetBluePixelComponent(q) > max_threshold)
+            if ((MagickRealType) GetPixelBlue(q) > max_threshold)
               threshold.blue=max_threshold;
             else
               threshold.blue=(MagickRealType) (QuantumRange*
@@ -1875,10 +1872,10 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
         }
       if ((channel & OpacityChannel) != 0)
         {
-          if ((MagickRealType) GetOpacityPixelComponent(q) < min_threshold)
+          if ((MagickRealType) GetPixelOpacity(q) < min_threshold)
             threshold.opacity=min_threshold;
           else
-            if ((MagickRealType) GetOpacityPixelComponent(q) > max_threshold)
+            if ((MagickRealType) GetPixelOpacity(q) > max_threshold)
               threshold.opacity=max_threshold;
             else
               threshold.opacity=(MagickRealType) (QuantumRange*
@@ -1887,31 +1884,31 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
       if (((channel & IndexChannel) != 0) &&
           (image->colorspace == CMYKColorspace))
         {
-          if ((MagickRealType) GetIndexPixelComponent(indexes+x) < min_threshold)
+          if ((MagickRealType) GetPixelIndex(indexes+x) < min_threshold)
             threshold.index=min_threshold;
           else
-            if ((MagickRealType) GetIndexPixelComponent(indexes+x) > max_threshold)
+            if ((MagickRealType) GetPixelIndex(indexes+x) > max_threshold)
               threshold.index=max_threshold;
             else
               threshold.index=(MagickRealType) (QuantumRange*
                 GetPseudoRandomValue(random_info[id]));
         }
       if ((channel & RedChannel) != 0)
-        SetRedPixelComponent(q,(MagickRealType) GetRedPixelComponent(q) <=
+        SetPixelRed(q,(MagickRealType) GetPixelRed(q) <=
           threshold.red ? 0 : QuantumRange);
       if ((channel & GreenChannel) != 0)
-        SetGreenPixelComponent(q,(MagickRealType) GetGreenPixelComponent(q) <=
+        SetPixelGreen(q,(MagickRealType) GetPixelGreen(q) <=
           threshold.green ? 0 : QuantumRange);
       if ((channel & BlueChannel) != 0)
-        SetBluePixelComponent(q,(MagickRealType) GetBluePixelComponent(q) <=
+        SetPixelBlue(q,(MagickRealType) GetPixelBlue(q) <=
           threshold.blue ? 0 : QuantumRange);
       if ((channel & OpacityChannel) != 0)
-        SetOpacityPixelComponent(q,(MagickRealType) GetOpacityPixelComponent(q)
+        SetPixelOpacity(q,(MagickRealType) GetPixelOpacity(q)
           <= threshold.opacity ? 0 : QuantumRange);
       if (((channel & IndexChannel) != 0) &&
           (image->colorspace == CMYKColorspace))
-        SetIndexPixelComponent(indexes+x,(MagickRealType)
-          GetIndexPixelComponent(indexes+x) <= threshold.index ? 0 :
+        SetPixelIndex(indexes+x,(MagickRealType)
+          GetPixelIndex(indexes+x) <= threshold.index ? 0 :
           QuantumRange);
       q++;
     }
@@ -2044,7 +2041,7 @@ MagickExport MagickBooleanType WhiteThresholdImageChannel(Image *image,
   progress=0;
   image_view=AcquireCacheView(image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(dynamic,4) shared(progress,status)
+  #pragma omp parallel for schedule(static,8) shared(progress,status)
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
   {
@@ -2068,36 +2065,36 @@ MagickExport MagickBooleanType WhiteThresholdImageChannel(Image *image,
     indexes=GetCacheViewAuthenticIndexQueue(image_view);
     for (x=0; x < (ssize_t) image->columns; x++)
     {
-      if (channel != DefaultChannels)
+      if (channel == DefaultChannels)
         {
           if (PixelIntensity(q) > MagickPixelIntensity(&threshold))
             {
-              SetRedPixelComponent(q,QuantumRange);
-              SetGreenPixelComponent(q,QuantumRange);
-              SetBluePixelComponent(q,QuantumRange);
+              SetPixelRed(q,QuantumRange);
+              SetPixelGreen(q,QuantumRange);
+              SetPixelBlue(q,QuantumRange);
               if (image->colorspace == CMYKColorspace)
-                SetIndexPixelComponent(indexes+x,QuantumRange);
+                SetPixelIndex(indexes+x,QuantumRange);
             }
         }
       else
         {
           if (((channel & RedChannel) != 0) &&
-              ((MagickRealType) GetRedPixelComponent(q) > threshold.red))
-            SetRedPixelComponent(q,QuantumRange);
+              ((MagickRealType) GetPixelRed(q) > threshold.red))
+            SetPixelRed(q,QuantumRange);
           if (((channel & GreenChannel) != 0) &&
-              ((MagickRealType) GetGreenPixelComponent(q) > threshold.green))
-            SetGreenPixelComponent(q,QuantumRange);
+              ((MagickRealType) GetPixelGreen(q) > threshold.green))
+            SetPixelGreen(q,QuantumRange);
           if (((channel & BlueChannel) != 0) &&
-              ((MagickRealType) GetBluePixelComponent(q) > threshold.blue))
-            SetBluePixelComponent(q,QuantumRange);
+              ((MagickRealType) GetPixelBlue(q) > threshold.blue))
+            SetPixelBlue(q,QuantumRange);
           if (((channel & OpacityChannel) != 0) &&
-              ((MagickRealType) GetOpacityPixelComponent(q) > threshold.opacity))
-            SetOpacityPixelComponent(q,QuantumRange);
+              ((MagickRealType) GetPixelOpacity(q) > threshold.opacity))
+            SetPixelOpacity(q,QuantumRange);
           if (((channel & IndexChannel) != 0) &&
               (image->colorspace == CMYKColorspace) &&
-              ((MagickRealType) GetIndexPixelComponent(indexes+x)) >
+              ((MagickRealType) GetPixelIndex(indexes+x)) >
               threshold.index)
-            SetIndexPixelComponent(indexes+x,QuantumRange);
+            SetPixelIndex(indexes+x,QuantumRange);
         }
       q++;
     }
