@@ -17,7 +17,7 @@
 %                              January 1993                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -1840,7 +1840,8 @@ MagickExport int SystemCommand(const MagickBooleanType asynchronous,
 #if !defined(MAGICKCORE_HAVE_EXECVP)
   status=system(shell_command);
 #else
-  if ((asynchronous != MagickFalse) || (strspn(shell_command,"&;<>|") == 0))
+  if ((asynchronous != MagickFalse) ||
+      (strpbrk(shell_command,"&;<>|") != (char *) NULL))
     status=system(shell_command);
   else
     {
@@ -1883,15 +1884,7 @@ MagickExport int SystemCommand(const MagickBooleanType asynchronous,
     }
 #endif
 #elif defined(MAGICKCORE_WINDOWS_SUPPORT)
-  {
-    int
-      mode;
-
-    mode=_P_WAIT;
-    if (asynchronous != MagickFalse)
-      mode=_P_NOWAIT;
-    status=spawnvp(mode,arguments[1],(const char **) (arguments+1));
-  }
+  status=NTSystemCommand(shell_command);
 #elif defined(macintosh)
   status=MACSystemCommand(shell_command);
 #elif defined(vms)
