@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
 
   You may not use this file except in compliance with the License.
@@ -211,6 +211,7 @@ extern WandExport MagickBooleanType
   MagickMagnifyImage(MagickWand *),
   MagickMedianFilterImage(MagickWand *,const double),
   MagickMinifyImage(MagickWand *),
+  MagickModeImage(MagickWand *,const double),
   MagickModulateImage(MagickWand *,const double,const double,const double),
   MagickMorphologyImage(MagickWand *,MorphologyMethod,const ssize_t,
     KernelInfo *),
@@ -337,6 +338,10 @@ extern WandExport MagickBooleanType
   MagickSpliceImage(MagickWand *,const size_t,const size_t,const ssize_t,
     const ssize_t),
   MagickSpreadImage(MagickWand *,const double),
+  MagickStatisticImage(MagickWand *,const ChannelType,const StatisticType,
+    const size_t,const size_t),
+  MagickStatisticImageChannel(MagickWand *,const StatisticType,const size_t,
+    const size_t),
   MagickStripImage(MagickWand *),
   MagickSwirlImage(MagickWand *,const double),
   MagickTintImage(MagickWand *,const PixelWand *,const PixelWand *),
@@ -390,6 +395,7 @@ extern WandExport MagickWand
   *MagickPreviewImages(MagickWand *wand,const PreviewType),
   *MagickSimilarityImage(MagickWand *,const MagickWand *,RectangleInfo *,
     double *),
+  *MagickSmushImages(MagickWand *,const MagickBooleanType,const ssize_t),
   *MagickSteganoImage(MagickWand *,const MagickWand *,const ssize_t),
   *MagickStereoImage(MagickWand *,const MagickWand *),
   *MagickTextureImage(MagickWand *,const MagickWand *),
